// This file has been generated by Py++.

#include "boost/python.hpp"
#include "generators/include/python_CEGUI.h"
#include "MultiLineEditbox.pypp.hpp"

namespace bp = boost::python;

struct MultiLineEditbox_wrapper : CEGUI::MultiLineEditbox, bp::wrapper< CEGUI::MultiLineEditbox > {

    MultiLineEditbox_wrapper(::CEGUI::String const & type, ::CEGUI::String const & name )
    : CEGUI::MultiLineEditbox( boost::ref(type), boost::ref(name) )
      , bp::wrapper< CEGUI::MultiLineEditbox >(){
        // constructor
    
    }

    void clearSelection(  ){
        CEGUI::MultiLineEditbox::clearSelection(  );
    }

    void configureScrollbars(  ){
        CEGUI::MultiLineEditbox::configureScrollbars(  );
    }

    void eraseSelectedText( bool modify_text=true ){
        CEGUI::MultiLineEditbox::eraseSelectedText( modify_text );
    }

    void formatText(  ){
        CEGUI::MultiLineEditbox::formatText(  );
    }

    ::size_t getNextTokenLength( ::CEGUI::String const & text, ::size_t start_idx ) const {
        return CEGUI::MultiLineEditbox::getNextTokenLength( boost::ref(text), start_idx );
    }

    ::size_t getTextIndexFromPosition( ::CEGUI::Vector2f const & pt ) const {
        return CEGUI::MultiLineEditbox::getTextIndexFromPosition( boost::ref(pt) );
    }

    void handleBackspace(  ){
        CEGUI::MultiLineEditbox::handleBackspace(  );
    }

    void handleCharLeft( ::CEGUI::uint sysKeys ){
        CEGUI::MultiLineEditbox::handleCharLeft( sysKeys );
    }

    void handleCharRight( ::CEGUI::uint sysKeys ){
        CEGUI::MultiLineEditbox::handleCharRight( sysKeys );
    }

    void handleDelete(  ){
        CEGUI::MultiLineEditbox::handleDelete(  );
    }

    void handleDocEnd( ::CEGUI::uint sysKeys ){
        CEGUI::MultiLineEditbox::handleDocEnd( sysKeys );
    }

    void handleDocHome( ::CEGUI::uint sysKeys ){
        CEGUI::MultiLineEditbox::handleDocHome( sysKeys );
    }

    void handleLineDown( ::CEGUI::uint sysKeys ){
        CEGUI::MultiLineEditbox::handleLineDown( sysKeys );
    }

    void handleLineEnd( ::CEGUI::uint sysKeys ){
        CEGUI::MultiLineEditbox::handleLineEnd( sysKeys );
    }

    void handleLineHome( ::CEGUI::uint sysKeys ){
        CEGUI::MultiLineEditbox::handleLineHome( sysKeys );
    }

    void handleLineUp( ::CEGUI::uint sysKeys ){
        CEGUI::MultiLineEditbox::handleLineUp( sysKeys );
    }

    void handleNewLine( ::CEGUI::uint sysKeys ){
        CEGUI::MultiLineEditbox::handleNewLine( sysKeys );
    }

    void handlePageDown( ::CEGUI::uint sysKeys ){
        CEGUI::MultiLineEditbox::handlePageDown( sysKeys );
    }

    void handlePageUp( ::CEGUI::uint sysKeys ){
        CEGUI::MultiLineEditbox::handlePageUp( sysKeys );
    }

    void handleWordLeft( ::CEGUI::uint sysKeys ){
        CEGUI::MultiLineEditbox::handleWordLeft( sysKeys );
    }

    void handleWordRight( ::CEGUI::uint sysKeys ){
        CEGUI::MultiLineEditbox::handleWordRight( sysKeys );
    }

    bool handle_scrollChange( ::CEGUI::EventArgs const & args ){
        return CEGUI::MultiLineEditbox::handle_scrollChange( boost::ref(args) );
    }

    bool handle_vertScrollbarVisibilityChanged( ::CEGUI::EventArgs const & arg0 ){
        return CEGUI::MultiLineEditbox::handle_vertScrollbarVisibilityChanged( boost::ref(arg0) );
    }

    virtual void initialiseComponents(  ) {
        if( bp::override func_initialiseComponents = this->get_override( "initialiseComponents" ) )
            func_initialiseComponents(  );
        else{
            this->CEGUI::MultiLineEditbox::initialiseComponents(  );
        }
    }
    
    void default_initialiseComponents(  ) {
        CEGUI::MultiLineEditbox::initialiseComponents( );
    }

    virtual void onCaptureLost( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onCaptureLost = this->get_override( "onCaptureLost" ) )
            func_onCaptureLost( boost::ref(e) );
        else{
            this->CEGUI::MultiLineEditbox::onCaptureLost( boost::ref(e) );
        }
    }
    
    virtual void default_onCaptureLost( ::CEGUI::WindowEventArgs & e ){
        CEGUI::MultiLineEditbox::onCaptureLost( boost::ref(e) );
    }

    void onCaretMoved( ::CEGUI::WindowEventArgs & e ){
        CEGUI::MultiLineEditbox::onCaretMoved( boost::ref(e) );
    }

    virtual void onCharacter( ::CEGUI::KeyEventArgs & e ){
        if( bp::override func_onCharacter = this->get_override( "onCharacter" ) )
            func_onCharacter( boost::ref(e) );
        else{
            this->CEGUI::MultiLineEditbox::onCharacter( boost::ref(e) );
        }
    }
    
    virtual void default_onCharacter( ::CEGUI::KeyEventArgs & e ){
        CEGUI::MultiLineEditbox::onCharacter( boost::ref(e) );
    }

    void onEditboxFullEvent( ::CEGUI::WindowEventArgs & e ){
        CEGUI::MultiLineEditbox::onEditboxFullEvent( boost::ref(e) );
    }

    virtual void onFontChanged( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onFontChanged = this->get_override( "onFontChanged" ) )
            func_onFontChanged( boost::ref(e) );
        else{
            this->CEGUI::MultiLineEditbox::onFontChanged( boost::ref(e) );
        }
    }
    
    virtual void default_onFontChanged( ::CEGUI::WindowEventArgs & e ){
        CEGUI::MultiLineEditbox::onFontChanged( boost::ref(e) );
    }

    void onHorzScrollbarModeChanged( ::CEGUI::WindowEventArgs & e ){
        CEGUI::MultiLineEditbox::onHorzScrollbarModeChanged( boost::ref(e) );
    }

    virtual void onKeyDown( ::CEGUI::KeyEventArgs & e ){
        if( bp::override func_onKeyDown = this->get_override( "onKeyDown" ) )
            func_onKeyDown( boost::ref(e) );
        else{
            this->CEGUI::MultiLineEditbox::onKeyDown( boost::ref(e) );
        }
    }
    
    virtual void default_onKeyDown( ::CEGUI::KeyEventArgs & e ){
        CEGUI::MultiLineEditbox::onKeyDown( boost::ref(e) );
    }

    void onMaximumTextLengthChanged( ::CEGUI::WindowEventArgs & e ){
        CEGUI::MultiLineEditbox::onMaximumTextLengthChanged( boost::ref(e) );
    }

    virtual void onMouseButtonDown( ::CEGUI::MouseEventArgs & e ){
        if( bp::override func_onMouseButtonDown = this->get_override( "onMouseButtonDown" ) )
            func_onMouseButtonDown( boost::ref(e) );
        else{
            this->CEGUI::MultiLineEditbox::onMouseButtonDown( boost::ref(e) );
        }
    }
    
    virtual void default_onMouseButtonDown( ::CEGUI::MouseEventArgs & e ){
        CEGUI::MultiLineEditbox::onMouseButtonDown( boost::ref(e) );
    }

    virtual void onMouseButtonUp( ::CEGUI::MouseEventArgs & e ){
        if( bp::override func_onMouseButtonUp = this->get_override( "onMouseButtonUp" ) )
            func_onMouseButtonUp( boost::ref(e) );
        else{
            this->CEGUI::MultiLineEditbox::onMouseButtonUp( boost::ref(e) );
        }
    }
    
    virtual void default_onMouseButtonUp( ::CEGUI::MouseEventArgs & e ){
        CEGUI::MultiLineEditbox::onMouseButtonUp( boost::ref(e) );
    }

    virtual void onMouseDoubleClicked( ::CEGUI::MouseEventArgs & e ){
        if( bp::override func_onMouseDoubleClicked = this->get_override( "onMouseDoubleClicked" ) )
            func_onMouseDoubleClicked( boost::ref(e) );
        else{
            this->CEGUI::MultiLineEditbox::onMouseDoubleClicked( boost::ref(e) );
        }
    }
    
    virtual void default_onMouseDoubleClicked( ::CEGUI::MouseEventArgs & e ){
        CEGUI::MultiLineEditbox::onMouseDoubleClicked( boost::ref(e) );
    }

    virtual void onMouseMove( ::CEGUI::MouseEventArgs & e ){
        if( bp::override func_onMouseMove = this->get_override( "onMouseMove" ) )
            func_onMouseMove( boost::ref(e) );
        else{
            this->CEGUI::MultiLineEditbox::onMouseMove( boost::ref(e) );
        }
    }
    
    virtual void default_onMouseMove( ::CEGUI::MouseEventArgs & e ){
        CEGUI::MultiLineEditbox::onMouseMove( boost::ref(e) );
    }

    virtual void onMouseTripleClicked( ::CEGUI::MouseEventArgs & e ){
        if( bp::override func_onMouseTripleClicked = this->get_override( "onMouseTripleClicked" ) )
            func_onMouseTripleClicked( boost::ref(e) );
        else{
            this->CEGUI::MultiLineEditbox::onMouseTripleClicked( boost::ref(e) );
        }
    }
    
    virtual void default_onMouseTripleClicked( ::CEGUI::MouseEventArgs & e ){
        CEGUI::MultiLineEditbox::onMouseTripleClicked( boost::ref(e) );
    }

    virtual void onMouseWheel( ::CEGUI::MouseEventArgs & e ){
        if( bp::override func_onMouseWheel = this->get_override( "onMouseWheel" ) )
            func_onMouseWheel( boost::ref(e) );
        else{
            this->CEGUI::MultiLineEditbox::onMouseWheel( boost::ref(e) );
        }
    }
    
    virtual void default_onMouseWheel( ::CEGUI::MouseEventArgs & e ){
        CEGUI::MultiLineEditbox::onMouseWheel( boost::ref(e) );
    }

    void onReadOnlyChanged( ::CEGUI::WindowEventArgs & e ){
        CEGUI::MultiLineEditbox::onReadOnlyChanged( boost::ref(e) );
    }

    virtual void onSized( ::CEGUI::ElementEventArgs & e ){
        if( bp::override func_onSized = this->get_override( "onSized" ) )
            func_onSized( boost::ref(e) );
        else{
            this->CEGUI::MultiLineEditbox::onSized( boost::ref(e) );
        }
    }
    
    virtual void default_onSized( ::CEGUI::ElementEventArgs & e ){
        CEGUI::MultiLineEditbox::onSized( boost::ref(e) );
    }

    virtual void onTextChanged( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onTextChanged = this->get_override( "onTextChanged" ) )
            func_onTextChanged( boost::ref(e) );
        else{
            this->CEGUI::MultiLineEditbox::onTextChanged( boost::ref(e) );
        }
    }
    
    virtual void default_onTextChanged( ::CEGUI::WindowEventArgs & e ){
        CEGUI::MultiLineEditbox::onTextChanged( boost::ref(e) );
    }

    void onTextSelectionChanged( ::CEGUI::WindowEventArgs & e ){
        CEGUI::MultiLineEditbox::onTextSelectionChanged( boost::ref(e) );
    }

    void onVertScrollbarModeChanged( ::CEGUI::WindowEventArgs & e ){
        CEGUI::MultiLineEditbox::onVertScrollbarModeChanged( boost::ref(e) );
    }

    void onWordWrapModeChanged( ::CEGUI::WindowEventArgs & e ){
        CEGUI::MultiLineEditbox::onWordWrapModeChanged( boost::ref(e) );
    }

    virtual bool performCopy( ::CEGUI::Clipboard & clipboard ) {
        if( bp::override func_performCopy = this->get_override( "performCopy" ) )
            return func_performCopy( boost::ref(clipboard) );
        else{
            return this->CEGUI::MultiLineEditbox::performCopy( boost::ref(clipboard) );
        }
    }
    
    bool default_performCopy( ::CEGUI::Clipboard & clipboard ) {
        return CEGUI::MultiLineEditbox::performCopy( boost::ref(clipboard) );
    }

    virtual bool performCut( ::CEGUI::Clipboard & clipboard ) {
        if( bp::override func_performCut = this->get_override( "performCut" ) )
            return func_performCut( boost::ref(clipboard) );
        else{
            return this->CEGUI::MultiLineEditbox::performCut( boost::ref(clipboard) );
        }
    }
    
    bool default_performCut( ::CEGUI::Clipboard & clipboard ) {
        return CEGUI::MultiLineEditbox::performCut( boost::ref(clipboard) );
    }

    virtual bool performPaste( ::CEGUI::Clipboard & clipboard ) {
        if( bp::override func_performPaste = this->get_override( "performPaste" ) )
            return func_performPaste( boost::ref(clipboard) );
        else{
            return this->CEGUI::MultiLineEditbox::performPaste( boost::ref(clipboard) );
        }
    }
    
    bool default_performPaste( ::CEGUI::Clipboard & clipboard ) {
        return CEGUI::MultiLineEditbox::performPaste( boost::ref(clipboard) );
    }

    virtual bool validateWindowRenderer( ::CEGUI::WindowRenderer const * renderer ) const {
        if( bp::override func_validateWindowRenderer = this->get_override( "validateWindowRenderer" ) )
            return func_validateWindowRenderer( boost::python::ptr(renderer) );
        else{
            return this->CEGUI::MultiLineEditbox::validateWindowRenderer( boost::python::ptr(renderer) );
        }
    }
    
    virtual bool default_validateWindowRenderer( ::CEGUI::WindowRenderer const * renderer ) const {
        return CEGUI::MultiLineEditbox::validateWindowRenderer( boost::python::ptr(renderer) );
    }

    virtual void addChild_impl( ::CEGUI::Element * element ){
        if( bp::override func_addChild_impl = this->get_override( "addChild_impl" ) )
            func_addChild_impl( boost::python::ptr(element) );
        else{
            this->CEGUI::Window::addChild_impl( boost::python::ptr(element) );
        }
    }
    
    virtual void default_addChild_impl( ::CEGUI::Element * element ){
        CEGUI::Window::addChild_impl( boost::python::ptr(element) );
    }

    void addElementProperties(  ){
        CEGUI::Element::addElementProperties(  );
    }

    void addNamedElementProperties(  ){
        CEGUI::NamedElement::addNamedElementProperties(  );
    }

    void addWindowProperties(  ){
        CEGUI::Window::addWindowProperties(  );
    }

    void addWindowToDrawList( ::CEGUI::Window & wnd, bool at_back=false ){
        CEGUI::Window::addWindowToDrawList( boost::ref(wnd), at_back );
    }

    void allocateRenderingWindow(  ){
        CEGUI::Window::allocateRenderingWindow(  );
    }

    virtual void banPropertiesForAutoWindow(  ){
        if( bp::override func_banPropertiesForAutoWindow = this->get_override( "banPropertiesForAutoWindow" ) )
            func_banPropertiesForAutoWindow(  );
        else{
            this->CEGUI::Window::banPropertiesForAutoWindow(  );
        }
    }
    
    virtual void default_banPropertiesForAutoWindow(  ){
        CEGUI::Window::banPropertiesForAutoWindow( );
    }

    virtual void beginInitialisation(  ) {
        if( bp::override func_beginInitialisation = this->get_override( "beginInitialisation" ) )
            func_beginInitialisation(  );
        else{
            this->CEGUI::Window::beginInitialisation(  );
        }
    }
    
    void default_beginInitialisation(  ) {
        CEGUI::Window::beginInitialisation( );
    }

    void bufferGeometry( ::CEGUI::RenderingContext const & ctx ){
        CEGUI::Window::bufferGeometry( boost::ref(ctx) );
    }

    virtual void cleanupChildren(  ){
        if( bp::override func_cleanupChildren = this->get_override( "cleanupChildren" ) )
            func_cleanupChildren(  );
        else{
            this->CEGUI::Window::cleanupChildren(  );
        }
    }
    
    virtual void default_cleanupChildren(  ){
        CEGUI::Window::cleanupChildren( );
    }

    virtual void cloneChildWidgetsTo( ::CEGUI::Window & target ) const  {
        if( bp::override func_cloneChildWidgetsTo = this->get_override( "cloneChildWidgetsTo" ) )
            func_cloneChildWidgetsTo( boost::ref(target) );
        else{
            this->CEGUI::Window::cloneChildWidgetsTo( boost::ref(target) );
        }
    }
    
    void default_cloneChildWidgetsTo( ::CEGUI::Window & target ) const  {
        CEGUI::Window::cloneChildWidgetsTo( boost::ref(target) );
    }

    virtual void clonePropertiesTo( ::CEGUI::Window & target ) const  {
        if( bp::override func_clonePropertiesTo = this->get_override( "clonePropertiesTo" ) )
            func_clonePropertiesTo( boost::ref(target) );
        else{
            this->CEGUI::Window::clonePropertiesTo( boost::ref(target) );
        }
    }
    
    void default_clonePropertiesTo( ::CEGUI::Window & target ) const  {
        CEGUI::Window::clonePropertiesTo( boost::ref(target) );
    }

    virtual void destroy(  ) {
        if( bp::override func_destroy = this->get_override( "destroy" ) )
            func_destroy(  );
        else{
            this->CEGUI::Window::destroy(  );
        }
    }
    
    void default_destroy(  ) {
        CEGUI::Window::destroy( );
    }

    virtual void drawSelf( ::CEGUI::RenderingContext const & ctx ){
        if( bp::override func_drawSelf = this->get_override( "drawSelf" ) )
            func_drawSelf( boost::ref(ctx) );
        else{
            this->CEGUI::Window::drawSelf( boost::ref(ctx) );
        }
    }
    
    virtual void default_drawSelf( ::CEGUI::RenderingContext const & ctx ){
        CEGUI::Window::drawSelf( boost::ref(ctx) );
    }

    virtual void endInitialisation(  ) {
        if( bp::override func_endInitialisation = this->get_override( "endInitialisation" ) )
            func_endInitialisation(  );
        else{
            this->CEGUI::Window::endInitialisation(  );
        }
    }
    
    void default_endInitialisation(  ) {
        CEGUI::Window::endInitialisation( );
    }

    void fireAreaChangeEvents( bool const moved, bool const sized ){
        CEGUI::Element::fireAreaChangeEvents( moved, sized );
    }

    virtual void fireEvent( ::CEGUI::String const & name, ::CEGUI::EventArgs & args, ::CEGUI::String const & eventNamespace="" ) {
        if( bp::override func_fireEvent = this->get_override( "fireEvent" ) )
            func_fireEvent( boost::ref(name), boost::ref(args), boost::ref(eventNamespace) );
        else{
            this->CEGUI::EventSet::fireEvent( boost::ref(name), boost::ref(args), boost::ref(eventNamespace) );
        }
    }
    
    void default_fireEvent( ::CEGUI::String const & name, ::CEGUI::EventArgs & args, ::CEGUI::String const & eventNamespace="" ) {
        CEGUI::EventSet::fireEvent( boost::ref(name), boost::ref(args), boost::ref(eventNamespace) );
    }

    void fireEvent_impl( ::CEGUI::String const & name, ::CEGUI::EventArgs & args ){
        CEGUI::EventSet::fireEvent_impl( boost::ref(name), boost::ref(args) );
    }

    void generateAutoRepeatEvent( ::CEGUI::MouseButton button ){
        CEGUI::Window::generateAutoRepeatEvent( button );
    }

    virtual ::CEGUI::NamedElement * getChildByNamePath_impl( ::CEGUI::String const & name_path ) const {
        if( bp::override func_getChildByNamePath_impl = this->get_override( "getChildByNamePath_impl" ) )
            return func_getChildByNamePath_impl( boost::ref(name_path) );
        else{
            return this->CEGUI::NamedElement::getChildByNamePath_impl( boost::ref(name_path) );
        }
    }
    
    virtual ::CEGUI::NamedElement * default_getChildByNamePath_impl( ::CEGUI::String const & name_path ) const {
        return CEGUI::NamedElement::getChildByNamePath_impl( boost::ref(name_path) );
    }

    virtual ::CEGUI::NamedElement * getChildByNameRecursive_impl( ::CEGUI::String const & name ) const {
        if( bp::override func_getChildByNameRecursive_impl = this->get_override( "getChildByNameRecursive_impl" ) )
            return func_getChildByNameRecursive_impl( boost::ref(name) );
        else{
            return this->CEGUI::NamedElement::getChildByNameRecursive_impl( boost::ref(name) );
        }
    }
    
    virtual ::CEGUI::NamedElement * default_getChildByNameRecursive_impl( ::CEGUI::String const & name ) const {
        return CEGUI::NamedElement::getChildByNameRecursive_impl( boost::ref(name) );
    }

    virtual ::CEGUI::Rectf getHitTestRect_impl(  ) const {
        if( bp::override func_getHitTestRect_impl = this->get_override( "getHitTestRect_impl" ) )
            return func_getHitTestRect_impl(  );
        else{
            return this->CEGUI::Window::getHitTestRect_impl(  );
        }
    }
    
    virtual ::CEGUI::Rectf default_getHitTestRect_impl(  ) const {
        return CEGUI::Window::getHitTestRect_impl( );
    }

    virtual ::CEGUI::Rectf getInnerRectClipper_impl(  ) const {
        if( bp::override func_getInnerRectClipper_impl = this->get_override( "getInnerRectClipper_impl" ) )
            return func_getInnerRectClipper_impl(  );
        else{
            return this->CEGUI::Window::getInnerRectClipper_impl(  );
        }
    }
    
    virtual ::CEGUI::Rectf default_getInnerRectClipper_impl(  ) const {
        return CEGUI::Window::getInnerRectClipper_impl( );
    }

    virtual ::CEGUI::Rectf getOuterRectClipper_impl(  ) const {
        if( bp::override func_getOuterRectClipper_impl = this->get_override( "getOuterRectClipper_impl" ) )
            return func_getOuterRectClipper_impl(  );
        else{
            return this->CEGUI::Window::getOuterRectClipper_impl(  );
        }
    }
    
    virtual ::CEGUI::Rectf default_getOuterRectClipper_impl(  ) const {
        return CEGUI::Window::getOuterRectClipper_impl( );
    }

    ::CEGUI::Rectf getParentElementClipIntersection( ::CEGUI::Rectf const & unclipped_area ) const {
        return CEGUI::Window::getParentElementClipIntersection( boost::ref(unclipped_area) );
    }

    virtual void getRenderingContext_impl( ::CEGUI::RenderingContext & ctx ) const  {
        if( bp::override func_getRenderingContext_impl = this->get_override( "getRenderingContext_impl" ) )
            func_getRenderingContext_impl( boost::ref(ctx) );
        else{
            this->CEGUI::Window::getRenderingContext_impl( boost::ref(ctx) );
        }
    }
    
    void default_getRenderingContext_impl( ::CEGUI::RenderingContext & ctx ) const  {
        CEGUI::Window::getRenderingContext_impl( boost::ref(ctx) );
    }

    ::CEGUI::ScriptModule * getScriptModule(  ) const {
        return CEGUI::EventSet::getScriptModule(  );
    }

    virtual ::CEGUI::Rectf getUnclippedInnerRect_impl( bool skipAllPixelAlignment ) const {
        if( bp::override func_getUnclippedInnerRect_impl = this->get_override( "getUnclippedInnerRect_impl" ) )
            return func_getUnclippedInnerRect_impl( skipAllPixelAlignment );
        else{
            return this->CEGUI::Window::getUnclippedInnerRect_impl( skipAllPixelAlignment );
        }
    }
    
    virtual ::CEGUI::Rectf default_getUnclippedInnerRect_impl( bool skipAllPixelAlignment ) const {
        return CEGUI::Window::getUnclippedInnerRect_impl( skipAllPixelAlignment );
    }

    virtual ::CEGUI::Rectf getUnclippedOuterRect_impl( bool skipAllPixelAlignment ) const {
        if( bp::override func_getUnclippedOuterRect_impl = this->get_override( "getUnclippedOuterRect_impl" ) )
            return func_getUnclippedOuterRect_impl( skipAllPixelAlignment );
        else{
            return this->CEGUI::Element::getUnclippedOuterRect_impl( skipAllPixelAlignment );
        }
    }
    
    virtual ::CEGUI::Rectf default_getUnclippedOuterRect_impl( bool skipAllPixelAlignment ) const {
        return CEGUI::Element::getUnclippedOuterRect_impl( skipAllPixelAlignment );
    }

    ::CEGUI::Window const * getWindowAttachedToCommonAncestor( ::CEGUI::Window const & wnd ) const {
        return CEGUI::Window::getWindowAttachedToCommonAncestor( boost::ref(wnd) );
    }

    virtual bool handleFontRenderSizeChange( ::CEGUI::EventArgs const & args ){
        if( bp::override func_handleFontRenderSizeChange = this->get_override( "handleFontRenderSizeChange" ) )
            return func_handleFontRenderSizeChange( boost::ref(args) );
        else{
            return this->CEGUI::Window::handleFontRenderSizeChange( boost::ref(args) );
        }
    }
    
    virtual bool default_handleFontRenderSizeChange( ::CEGUI::EventArgs const & args ){
        return CEGUI::Window::handleFontRenderSizeChange( boost::ref(args) );
    }

    void initialiseClippers( ::CEGUI::RenderingContext const & ctx ){
        CEGUI::Window::initialiseClippers( boost::ref(ctx) );
    }

    void invalidate_impl( bool const recursive ){
        CEGUI::Window::invalidate_impl( recursive );
    }

    virtual bool isHit( ::CEGUI::Vector2f const & position, bool const allow_disabled=false ) const  {
        if( bp::override func_isHit = this->get_override( "isHit" ) )
            return func_isHit( boost::ref(position), allow_disabled );
        else{
            return this->CEGUI::Window::isHit( boost::ref(position), allow_disabled );
        }
    }
    
    bool default_isHit( ::CEGUI::Vector2f const & position, bool const allow_disabled=false ) const  {
        return CEGUI::Window::isHit( boost::ref(position), allow_disabled );
    }

    bool isHitTargetWindow( ::CEGUI::Vector2f const & position, bool allow_disabled ) const {
        return CEGUI::Window::isHitTargetWindow( boost::ref(position), allow_disabled );
    }

    bool isInnerRectSizeChanged(  ) const {
        return CEGUI::Element::isInnerRectSizeChanged(  );
    }

    bool isPropertyAtDefault( ::CEGUI::Property const * property ) const {
        return CEGUI::Window::isPropertyAtDefault( boost::python::ptr(property) );
    }

    bool isTopOfZOrder(  ) const {
        return CEGUI::Window::isTopOfZOrder(  );
    }

    void layoutLookNFeelChildWidgets(  ){
        CEGUI::Window::layoutLookNFeelChildWidgets(  );
    }

    void markCachedWindowRectsInvalid(  ){
        CEGUI::Window::markCachedWindowRectsInvalid(  );
    }

    virtual bool moveToFront_impl( bool wasClicked ){
        if( bp::override func_moveToFront_impl = this->get_override( "moveToFront_impl" ) )
            return func_moveToFront_impl( wasClicked );
        else{
            return this->CEGUI::Window::moveToFront_impl( wasClicked );
        }
    }
    
    virtual bool default_moveToFront_impl( bool wasClicked ){
        return CEGUI::Window::moveToFront_impl( wasClicked );
    }

    void notifyChildrenOfSizeChange( bool const non_client, bool const client ){
        CEGUI::Element::notifyChildrenOfSizeChange( non_client, client );
    }

    void notifyClippingChanged(  ){
        CEGUI::Window::notifyClippingChanged(  );
    }

    virtual void notifyScreenAreaChanged( bool recursive=true ) {
        if( bp::override func_notifyScreenAreaChanged = this->get_override( "notifyScreenAreaChanged" ) )
            func_notifyScreenAreaChanged( recursive );
        else{
            this->CEGUI::Window::notifyScreenAreaChanged( recursive );
        }
    }
    
    void default_notifyScreenAreaChanged( bool recursive=true ) {
        CEGUI::Window::notifyScreenAreaChanged( recursive );
    }

    virtual void onActivated( ::CEGUI::ActivationEventArgs & e ){
        if( bp::override func_onActivated = this->get_override( "onActivated" ) )
            func_onActivated( boost::ref(e) );
        else{
            this->CEGUI::Window::onActivated( boost::ref(e) );
        }
    }
    
    virtual void default_onActivated( ::CEGUI::ActivationEventArgs & e ){
        CEGUI::Window::onActivated( boost::ref(e) );
    }

    virtual void onAlphaChanged( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onAlphaChanged = this->get_override( "onAlphaChanged" ) )
            func_onAlphaChanged( boost::ref(e) );
        else{
            this->CEGUI::Window::onAlphaChanged( boost::ref(e) );
        }
    }
    
    virtual void default_onAlphaChanged( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Window::onAlphaChanged( boost::ref(e) );
    }

    virtual void onAlwaysOnTopChanged( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onAlwaysOnTopChanged = this->get_override( "onAlwaysOnTopChanged" ) )
            func_onAlwaysOnTopChanged( boost::ref(e) );
        else{
            this->CEGUI::Window::onAlwaysOnTopChanged( boost::ref(e) );
        }
    }
    
    virtual void default_onAlwaysOnTopChanged( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Window::onAlwaysOnTopChanged( boost::ref(e) );
    }

    virtual void onCaptureGained( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onCaptureGained = this->get_override( "onCaptureGained" ) )
            func_onCaptureGained( boost::ref(e) );
        else{
            this->CEGUI::Window::onCaptureGained( boost::ref(e) );
        }
    }
    
    virtual void default_onCaptureGained( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Window::onCaptureGained( boost::ref(e) );
    }

    virtual void onChildAdded( ::CEGUI::ElementEventArgs & e ){
        if( bp::override func_onChildAdded = this->get_override( "onChildAdded" ) )
            func_onChildAdded( boost::ref(e) );
        else{
            this->CEGUI::Window::onChildAdded( boost::ref(e) );
        }
    }
    
    virtual void default_onChildAdded( ::CEGUI::ElementEventArgs & e ){
        CEGUI::Window::onChildAdded( boost::ref(e) );
    }

    virtual void onChildRemoved( ::CEGUI::ElementEventArgs & e ){
        if( bp::override func_onChildRemoved = this->get_override( "onChildRemoved" ) )
            func_onChildRemoved( boost::ref(e) );
        else{
            this->CEGUI::Window::onChildRemoved( boost::ref(e) );
        }
    }
    
    virtual void default_onChildRemoved( ::CEGUI::ElementEventArgs & e ){
        CEGUI::Window::onChildRemoved( boost::ref(e) );
    }

    virtual void onClippingChanged( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onClippingChanged = this->get_override( "onClippingChanged" ) )
            func_onClippingChanged( boost::ref(e) );
        else{
            this->CEGUI::Window::onClippingChanged( boost::ref(e) );
        }
    }
    
    virtual void default_onClippingChanged( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Window::onClippingChanged( boost::ref(e) );
    }

    virtual void onDeactivated( ::CEGUI::ActivationEventArgs & e ){
        if( bp::override func_onDeactivated = this->get_override( "onDeactivated" ) )
            func_onDeactivated( boost::ref(e) );
        else{
            this->CEGUI::Window::onDeactivated( boost::ref(e) );
        }
    }
    
    virtual void default_onDeactivated( ::CEGUI::ActivationEventArgs & e ){
        CEGUI::Window::onDeactivated( boost::ref(e) );
    }

    virtual void onDestructionStarted( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onDestructionStarted = this->get_override( "onDestructionStarted" ) )
            func_onDestructionStarted( boost::ref(e) );
        else{
            this->CEGUI::Window::onDestructionStarted( boost::ref(e) );
        }
    }
    
    virtual void default_onDestructionStarted( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Window::onDestructionStarted( boost::ref(e) );
    }

    virtual void onDisabled( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onDisabled = this->get_override( "onDisabled" ) )
            func_onDisabled( boost::ref(e) );
        else{
            this->CEGUI::Window::onDisabled( boost::ref(e) );
        }
    }
    
    virtual void default_onDisabled( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Window::onDisabled( boost::ref(e) );
    }

    virtual void onDragDropItemDropped( ::CEGUI::DragDropEventArgs & e ){
        if( bp::override func_onDragDropItemDropped = this->get_override( "onDragDropItemDropped" ) )
            func_onDragDropItemDropped( boost::ref(e) );
        else{
            this->CEGUI::Window::onDragDropItemDropped( boost::ref(e) );
        }
    }
    
    virtual void default_onDragDropItemDropped( ::CEGUI::DragDropEventArgs & e ){
        CEGUI::Window::onDragDropItemDropped( boost::ref(e) );
    }

    virtual void onDragDropItemEnters( ::CEGUI::DragDropEventArgs & e ){
        if( bp::override func_onDragDropItemEnters = this->get_override( "onDragDropItemEnters" ) )
            func_onDragDropItemEnters( boost::ref(e) );
        else{
            this->CEGUI::Window::onDragDropItemEnters( boost::ref(e) );
        }
    }
    
    virtual void default_onDragDropItemEnters( ::CEGUI::DragDropEventArgs & e ){
        CEGUI::Window::onDragDropItemEnters( boost::ref(e) );
    }

    virtual void onDragDropItemLeaves( ::CEGUI::DragDropEventArgs & e ){
        if( bp::override func_onDragDropItemLeaves = this->get_override( "onDragDropItemLeaves" ) )
            func_onDragDropItemLeaves( boost::ref(e) );
        else{
            this->CEGUI::Window::onDragDropItemLeaves( boost::ref(e) );
        }
    }
    
    virtual void default_onDragDropItemLeaves( ::CEGUI::DragDropEventArgs & e ){
        CEGUI::Window::onDragDropItemLeaves( boost::ref(e) );
    }

    virtual void onEnabled( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onEnabled = this->get_override( "onEnabled" ) )
            func_onEnabled( boost::ref(e) );
        else{
            this->CEGUI::Window::onEnabled( boost::ref(e) );
        }
    }
    
    virtual void default_onEnabled( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Window::onEnabled( boost::ref(e) );
    }

    virtual void onHidden( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onHidden = this->get_override( "onHidden" ) )
            func_onHidden( boost::ref(e) );
        else{
            this->CEGUI::Window::onHidden( boost::ref(e) );
        }
    }
    
    virtual void default_onHidden( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Window::onHidden( boost::ref(e) );
    }

    virtual void onHorizontalAlignmentChanged( ::CEGUI::ElementEventArgs & e ){
        if( bp::override func_onHorizontalAlignmentChanged = this->get_override( "onHorizontalAlignmentChanged" ) )
            func_onHorizontalAlignmentChanged( boost::ref(e) );
        else{
            this->CEGUI::Element::onHorizontalAlignmentChanged( boost::ref(e) );
        }
    }
    
    virtual void default_onHorizontalAlignmentChanged( ::CEGUI::ElementEventArgs & e ){
        CEGUI::Element::onHorizontalAlignmentChanged( boost::ref(e) );
    }

    virtual void onIDChanged( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onIDChanged = this->get_override( "onIDChanged" ) )
            func_onIDChanged( boost::ref(e) );
        else{
            this->CEGUI::Window::onIDChanged( boost::ref(e) );
        }
    }
    
    virtual void default_onIDChanged( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Window::onIDChanged( boost::ref(e) );
    }

    virtual void onInheritsAlphaChanged( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onInheritsAlphaChanged = this->get_override( "onInheritsAlphaChanged" ) )
            func_onInheritsAlphaChanged( boost::ref(e) );
        else{
            this->CEGUI::Window::onInheritsAlphaChanged( boost::ref(e) );
        }
    }
    
    virtual void default_onInheritsAlphaChanged( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Window::onInheritsAlphaChanged( boost::ref(e) );
    }

    virtual void onInvalidated( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onInvalidated = this->get_override( "onInvalidated" ) )
            func_onInvalidated( boost::ref(e) );
        else{
            this->CEGUI::Window::onInvalidated( boost::ref(e) );
        }
    }
    
    virtual void default_onInvalidated( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Window::onInvalidated( boost::ref(e) );
    }

    virtual void onKeyUp( ::CEGUI::KeyEventArgs & e ){
        if( bp::override func_onKeyUp = this->get_override( "onKeyUp" ) )
            func_onKeyUp( boost::ref(e) );
        else{
            this->CEGUI::Window::onKeyUp( boost::ref(e) );
        }
    }
    
    virtual void default_onKeyUp( ::CEGUI::KeyEventArgs & e ){
        CEGUI::Window::onKeyUp( boost::ref(e) );
    }

    virtual void onMarginChanged( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onMarginChanged = this->get_override( "onMarginChanged" ) )
            func_onMarginChanged( boost::ref(e) );
        else{
            this->CEGUI::Window::onMarginChanged( boost::ref(e) );
        }
    }
    
    virtual void default_onMarginChanged( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Window::onMarginChanged( boost::ref(e) );
    }

    virtual void onMouseClicked( ::CEGUI::MouseEventArgs & e ){
        if( bp::override func_onMouseClicked = this->get_override( "onMouseClicked" ) )
            func_onMouseClicked( boost::ref(e) );
        else{
            this->CEGUI::Window::onMouseClicked( boost::ref(e) );
        }
    }
    
    virtual void default_onMouseClicked( ::CEGUI::MouseEventArgs & e ){
        CEGUI::Window::onMouseClicked( boost::ref(e) );
    }

    virtual void onMouseEnters( ::CEGUI::MouseEventArgs & e ){
        if( bp::override func_onMouseEnters = this->get_override( "onMouseEnters" ) )
            func_onMouseEnters( boost::ref(e) );
        else{
            this->CEGUI::Window::onMouseEnters( boost::ref(e) );
        }
    }
    
    virtual void default_onMouseEnters( ::CEGUI::MouseEventArgs & e ){
        CEGUI::Window::onMouseEnters( boost::ref(e) );
    }

    virtual void onMouseEntersArea( ::CEGUI::MouseEventArgs & e ){
        if( bp::override func_onMouseEntersArea = this->get_override( "onMouseEntersArea" ) )
            func_onMouseEntersArea( boost::ref(e) );
        else{
            this->CEGUI::Window::onMouseEntersArea( boost::ref(e) );
        }
    }
    
    virtual void default_onMouseEntersArea( ::CEGUI::MouseEventArgs & e ){
        CEGUI::Window::onMouseEntersArea( boost::ref(e) );
    }

    virtual void onMouseLeaves( ::CEGUI::MouseEventArgs & e ){
        if( bp::override func_onMouseLeaves = this->get_override( "onMouseLeaves" ) )
            func_onMouseLeaves( boost::ref(e) );
        else{
            this->CEGUI::Window::onMouseLeaves( boost::ref(e) );
        }
    }
    
    virtual void default_onMouseLeaves( ::CEGUI::MouseEventArgs & e ){
        CEGUI::Window::onMouseLeaves( boost::ref(e) );
    }

    virtual void onMouseLeavesArea( ::CEGUI::MouseEventArgs & e ){
        if( bp::override func_onMouseLeavesArea = this->get_override( "onMouseLeavesArea" ) )
            func_onMouseLeavesArea( boost::ref(e) );
        else{
            this->CEGUI::Window::onMouseLeavesArea( boost::ref(e) );
        }
    }
    
    virtual void default_onMouseLeavesArea( ::CEGUI::MouseEventArgs & e ){
        CEGUI::Window::onMouseLeavesArea( boost::ref(e) );
    }

    virtual void onMoved( ::CEGUI::ElementEventArgs & e ){
        if( bp::override func_onMoved = this->get_override( "onMoved" ) )
            func_onMoved( boost::ref(e) );
        else{
            this->CEGUI::Window::onMoved( boost::ref(e) );
        }
    }
    
    virtual void default_onMoved( ::CEGUI::ElementEventArgs & e ){
        CEGUI::Window::onMoved( boost::ref(e) );
    }

    virtual void onNameChanged( ::CEGUI::NamedElementEventArgs & e ){
        if( bp::override func_onNameChanged = this->get_override( "onNameChanged" ) )
            func_onNameChanged( boost::ref(e) );
        else{
            this->CEGUI::NamedElement::onNameChanged( boost::ref(e) );
        }
    }
    
    virtual void default_onNameChanged( ::CEGUI::NamedElementEventArgs & e ){
        CEGUI::NamedElement::onNameChanged( boost::ref(e) );
    }

    virtual void onNonClientChanged( ::CEGUI::ElementEventArgs & e ){
        if( bp::override func_onNonClientChanged = this->get_override( "onNonClientChanged" ) )
            func_onNonClientChanged( boost::ref(e) );
        else{
            this->CEGUI::Element::onNonClientChanged( boost::ref(e) );
        }
    }
    
    virtual void default_onNonClientChanged( ::CEGUI::ElementEventArgs & e ){
        CEGUI::Element::onNonClientChanged( boost::ref(e) );
    }

    virtual void onParentDestroyChanged( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onParentDestroyChanged = this->get_override( "onParentDestroyChanged" ) )
            func_onParentDestroyChanged( boost::ref(e) );
        else{
            this->CEGUI::Window::onParentDestroyChanged( boost::ref(e) );
        }
    }
    
    virtual void default_onParentDestroyChanged( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Window::onParentDestroyChanged( boost::ref(e) );
    }

    virtual void onParentSized( ::CEGUI::ElementEventArgs & e ){
        if( bp::override func_onParentSized = this->get_override( "onParentSized" ) )
            func_onParentSized( boost::ref(e) );
        else{
            this->CEGUI::Window::onParentSized( boost::ref(e) );
        }
    }
    
    virtual void default_onParentSized( ::CEGUI::ElementEventArgs & e ){
        CEGUI::Window::onParentSized( boost::ref(e) );
    }

    virtual void onRenderingEnded( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onRenderingEnded = this->get_override( "onRenderingEnded" ) )
            func_onRenderingEnded( boost::ref(e) );
        else{
            this->CEGUI::Window::onRenderingEnded( boost::ref(e) );
        }
    }
    
    virtual void default_onRenderingEnded( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Window::onRenderingEnded( boost::ref(e) );
    }

    virtual void onRenderingStarted( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onRenderingStarted = this->get_override( "onRenderingStarted" ) )
            func_onRenderingStarted( boost::ref(e) );
        else{
            this->CEGUI::Window::onRenderingStarted( boost::ref(e) );
        }
    }
    
    virtual void default_onRenderingStarted( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Window::onRenderingStarted( boost::ref(e) );
    }

    virtual void onRotated( ::CEGUI::ElementEventArgs & e ){
        if( bp::override func_onRotated = this->get_override( "onRotated" ) )
            func_onRotated( boost::ref(e) );
        else{
            this->CEGUI::Window::onRotated( boost::ref(e) );
        }
    }
    
    virtual void default_onRotated( ::CEGUI::ElementEventArgs & e ){
        CEGUI::Window::onRotated( boost::ref(e) );
    }

    virtual void onShown( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onShown = this->get_override( "onShown" ) )
            func_onShown( boost::ref(e) );
        else{
            this->CEGUI::Window::onShown( boost::ref(e) );
        }
    }
    
    virtual void default_onShown( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Window::onShown( boost::ref(e) );
    }

    virtual void onTextParsingChanged( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onTextParsingChanged = this->get_override( "onTextParsingChanged" ) )
            func_onTextParsingChanged( boost::ref(e) );
        else{
            this->CEGUI::Window::onTextParsingChanged( boost::ref(e) );
        }
    }
    
    virtual void default_onTextParsingChanged( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Window::onTextParsingChanged( boost::ref(e) );
    }

    virtual void onVerticalAlignmentChanged( ::CEGUI::ElementEventArgs & e ){
        if( bp::override func_onVerticalAlignmentChanged = this->get_override( "onVerticalAlignmentChanged" ) )
            func_onVerticalAlignmentChanged( boost::ref(e) );
        else{
            this->CEGUI::Element::onVerticalAlignmentChanged( boost::ref(e) );
        }
    }
    
    virtual void default_onVerticalAlignmentChanged( ::CEGUI::ElementEventArgs & e ){
        CEGUI::Element::onVerticalAlignmentChanged( boost::ref(e) );
    }

    virtual void onWindowRendererAttached( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onWindowRendererAttached = this->get_override( "onWindowRendererAttached" ) )
            func_onWindowRendererAttached( boost::ref(e) );
        else{
            this->CEGUI::Window::onWindowRendererAttached( boost::ref(e) );
        }
    }
    
    virtual void default_onWindowRendererAttached( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Window::onWindowRendererAttached( boost::ref(e) );
    }

    virtual void onWindowRendererDetached( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onWindowRendererDetached = this->get_override( "onWindowRendererDetached" ) )
            func_onWindowRendererDetached( boost::ref(e) );
        else{
            this->CEGUI::Window::onWindowRendererDetached( boost::ref(e) );
        }
    }
    
    virtual void default_onWindowRendererDetached( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Window::onWindowRendererDetached( boost::ref(e) );
    }

    virtual void onZChange_impl(  ){
        if( bp::override func_onZChange_impl = this->get_override( "onZChange_impl" ) )
            func_onZChange_impl(  );
        else{
            this->CEGUI::Window::onZChange_impl(  );
        }
    }
    
    virtual void default_onZChange_impl(  ){
        CEGUI::Window::onZChange_impl( );
    }

    virtual void onZChanged( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onZChanged = this->get_override( "onZChanged" ) )
            func_onZChanged( boost::ref(e) );
        else{
            this->CEGUI::Window::onZChanged( boost::ref(e) );
        }
    }
    
    virtual void default_onZChanged( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Window::onZChanged( boost::ref(e) );
    }

    virtual void performChildWindowLayout( bool nonclient_sized_hint=false, bool client_sized_hint=false ) {
        if( bp::override func_performChildWindowLayout = this->get_override( "performChildWindowLayout" ) )
            func_performChildWindowLayout( nonclient_sized_hint, client_sized_hint );
        else{
            this->CEGUI::Window::performChildWindowLayout( nonclient_sized_hint, client_sized_hint );
        }
    }
    
    void default_performChildWindowLayout( bool nonclient_sized_hint=false, bool client_sized_hint=false ) {
        CEGUI::Window::performChildWindowLayout( nonclient_sized_hint, client_sized_hint );
    }

    virtual void populateGeometryBuffer(  ){
        if( bp::override func_populateGeometryBuffer = this->get_override( "populateGeometryBuffer" ) )
            func_populateGeometryBuffer(  );
        else{
            this->CEGUI::Window::populateGeometryBuffer(  );
        }
    }
    
    virtual void default_populateGeometryBuffer(  ){
        CEGUI::Window::populateGeometryBuffer( );
    }

    void queueGeometry( ::CEGUI::RenderingContext const & ctx ){
        CEGUI::Window::queueGeometry( boost::ref(ctx) );
    }

    void releaseRenderingWindow(  ){
        CEGUI::Window::releaseRenderingWindow(  );
    }

    virtual void removeChild_impl( ::CEGUI::Element * element ){
        if( bp::override func_removeChild_impl = this->get_override( "removeChild_impl" ) )
            func_removeChild_impl( boost::python::ptr(element) );
        else{
            this->CEGUI::Window::removeChild_impl( boost::python::ptr(element) );
        }
    }
    
    virtual void default_removeChild_impl( ::CEGUI::Element * element ){
        CEGUI::Window::removeChild_impl( boost::python::ptr(element) );
    }

    void removeWindowFromDrawList( ::CEGUI::Window const & wnd ){
        CEGUI::Window::removeWindowFromDrawList( boost::ref(wnd) );
    }

    virtual void setArea( ::CEGUI::UVector2 const & pos, ::CEGUI::USize const & size ) {
        if( bp::override func_setArea = this->get_override( "setArea" ) )
            func_setArea( boost::ref(pos), boost::ref(size) );
        else{
            this->CEGUI::Element::setArea( boost::ref(pos), boost::ref(size) );
        }
    }
    
    void default_setArea( ::CEGUI::UVector2 const & pos, ::CEGUI::USize const & size ) {
        CEGUI::Element::setArea( boost::ref(pos), boost::ref(size) );
    }

    virtual void setArea_impl( ::CEGUI::UVector2 const & pos, ::CEGUI::USize const & size, bool topLeftSizing=false, bool fireEvents=true ){
        if( bp::override func_setArea_impl = this->get_override( "setArea_impl" ) )
            func_setArea_impl( boost::ref(pos), boost::ref(size), topLeftSizing, fireEvents );
        else{
            this->CEGUI::Window::setArea_impl( boost::ref(pos), boost::ref(size), topLeftSizing, fireEvents );
        }
    }
    
    virtual void default_setArea_impl( ::CEGUI::UVector2 const & pos, ::CEGUI::USize const & size, bool topLeftSizing=false, bool fireEvents=true ){
        CEGUI::Window::setArea_impl( boost::ref(pos), boost::ref(size), topLeftSizing, fireEvents );
    }

    virtual void setHorizontalAlignment( ::CEGUI::HorizontalAlignment const alignment ) {
        if( bp::override func_setHorizontalAlignment = this->get_override( "setHorizontalAlignment" ) )
            func_setHorizontalAlignment( alignment );
        else{
            this->CEGUI::Element::setHorizontalAlignment( alignment );
        }
    }
    
    void default_setHorizontalAlignment( ::CEGUI::HorizontalAlignment const alignment ) {
        CEGUI::Element::setHorizontalAlignment( alignment );
    }

    virtual void setLookNFeel( ::CEGUI::String const & look ) {
        if( bp::override func_setLookNFeel = this->get_override( "setLookNFeel" ) )
            func_setLookNFeel( boost::ref(look) );
        else{
            this->CEGUI::Window::setLookNFeel( boost::ref(look) );
        }
    }
    
    void default_setLookNFeel( ::CEGUI::String const & look ) {
        CEGUI::Window::setLookNFeel( boost::ref(look) );
    }

    virtual void setMargin( ::CEGUI::UBox const & margin ) {
        if( bp::override func_setMargin = this->get_override( "setMargin" ) )
            func_setMargin( boost::ref(margin) );
        else{
            this->CEGUI::Window::setMargin( boost::ref(margin) );
        }
    }
    
    void default_setMargin( ::CEGUI::UBox const & margin ) {
        CEGUI::Window::setMargin( boost::ref(margin) );
    }

    virtual void setName( ::CEGUI::String const & name ) {
        if( bp::override func_setName = this->get_override( "setName" ) )
            func_setName( boost::ref(name) );
        else{
            this->CEGUI::NamedElement::setName( boost::ref(name) );
        }
    }
    
    void default_setName( ::CEGUI::String const & name ) {
        CEGUI::NamedElement::setName( boost::ref(name) );
    }

    virtual void setParent( ::CEGUI::Element * parent ){
        if( bp::override func_setParent = this->get_override( "setParent" ) )
            func_setParent( boost::python::ptr(parent) );
        else{
            this->CEGUI::Window::setParent( boost::python::ptr(parent) );
        }
    }
    
    virtual void default_setParent( ::CEGUI::Element * parent ){
        CEGUI::Window::setParent( boost::python::ptr(parent) );
    }

    virtual void setVerticalAlignment( ::CEGUI::VerticalAlignment const alignment ) {
        if( bp::override func_setVerticalAlignment = this->get_override( "setVerticalAlignment" ) )
            func_setVerticalAlignment( alignment );
        else{
            this->CEGUI::Element::setVerticalAlignment( alignment );
        }
    }
    
    void default_setVerticalAlignment( ::CEGUI::VerticalAlignment const alignment ) {
        CEGUI::Element::setVerticalAlignment( alignment );
    }

    virtual ::CEGUI::RefCounted< CEGUI::BoundSlot > subscribeScriptedEvent( ::CEGUI::String const & name, ::CEGUI::String const & subscriber_name ) {
        if( bp::override func_subscribeScriptedEvent = this->get_override( "subscribeScriptedEvent" ) )
            return func_subscribeScriptedEvent( boost::ref(name), boost::ref(subscriber_name) );
        else{
            return this->CEGUI::EventSet::subscribeScriptedEvent( boost::ref(name), boost::ref(subscriber_name) );
        }
    }
    
    ::CEGUI::RefCounted< CEGUI::BoundSlot > default_subscribeScriptedEvent( ::CEGUI::String const & name, ::CEGUI::String const & subscriber_name ) {
        return CEGUI::EventSet::subscribeScriptedEvent( boost::ref(name), boost::ref(subscriber_name) );
    }

    virtual ::CEGUI::RefCounted< CEGUI::BoundSlot > subscribeScriptedEvent( ::CEGUI::String const & name, unsigned int group, ::CEGUI::String const & subscriber_name ) {
        if( bp::override func_subscribeScriptedEvent = this->get_override( "subscribeScriptedEvent" ) )
            return func_subscribeScriptedEvent( boost::ref(name), group, boost::ref(subscriber_name) );
        else{
            return this->CEGUI::EventSet::subscribeScriptedEvent( boost::ref(name), group, boost::ref(subscriber_name) );
        }
    }
    
    ::CEGUI::RefCounted< CEGUI::BoundSlot > default_subscribeScriptedEvent( ::CEGUI::String const & name, unsigned int group, ::CEGUI::String const & subscriber_name ) {
        return CEGUI::EventSet::subscribeScriptedEvent( boost::ref(name), group, boost::ref(subscriber_name) );
    }

    void transferChildSurfaces(  ){
        CEGUI::Window::transferChildSurfaces(  );
    }

    virtual void update( float elapsed ) {
        if( bp::override func_update = this->get_override( "update" ) )
            func_update( elapsed );
        else{
            this->CEGUI::Window::update( elapsed );
        }
    }
    
    void default_update( float elapsed ) {
        CEGUI::Window::update( elapsed );
    }

    void updateGeometryRenderSettings(  ){
        CEGUI::Window::updateGeometryRenderSettings(  );
    }

    virtual void updateSelf( float elapsed ){
        if( bp::override func_updateSelf = this->get_override( "updateSelf" ) )
            func_updateSelf( elapsed );
        else{
            this->CEGUI::Window::updateSelf( elapsed );
        }
    }
    
    virtual void default_updateSelf( float elapsed ){
        CEGUI::Window::updateSelf( elapsed );
    }

    virtual bool writeAutoChildWindowXML( ::CEGUI::XMLSerializer & xml_stream ) const {
        if( bp::override func_writeAutoChildWindowXML = this->get_override( "writeAutoChildWindowXML" ) )
            return func_writeAutoChildWindowXML( boost::ref(xml_stream) );
        else{
            return this->CEGUI::Window::writeAutoChildWindowXML( boost::ref(xml_stream) );
        }
    }
    
    virtual bool default_writeAutoChildWindowXML( ::CEGUI::XMLSerializer & xml_stream ) const {
        return CEGUI::Window::writeAutoChildWindowXML( boost::ref(xml_stream) );
    }

    virtual int writeChildWindowsXML( ::CEGUI::XMLSerializer & xml_stream ) const {
        if( bp::override func_writeChildWindowsXML = this->get_override( "writeChildWindowsXML" ) )
            return func_writeChildWindowsXML( boost::ref(xml_stream) );
        else{
            return this->CEGUI::Window::writeChildWindowsXML( boost::ref(xml_stream) );
        }
    }
    
    virtual int default_writeChildWindowsXML( ::CEGUI::XMLSerializer & xml_stream ) const {
        return CEGUI::Window::writeChildWindowsXML( boost::ref(xml_stream) );
    }

    virtual int writePropertiesXML( ::CEGUI::XMLSerializer & xml_stream ) const {
        if( bp::override func_writePropertiesXML = this->get_override( "writePropertiesXML" ) )
            return func_writePropertiesXML( boost::ref(xml_stream) );
        else{
            return this->CEGUI::Window::writePropertiesXML( boost::ref(xml_stream) );
        }
    }
    
    virtual int default_writePropertiesXML( ::CEGUI::XMLSerializer & xml_stream ) const {
        return CEGUI::Window::writePropertiesXML( boost::ref(xml_stream) );
    }

    virtual void writeXMLToStream( ::CEGUI::XMLSerializer & xml_stream ) const  {
        if( bp::override func_writeXMLToStream = this->get_override( "writeXMLToStream" ) )
            func_writeXMLToStream( boost::ref(xml_stream) );
        else{
            this->CEGUI::Window::writeXMLToStream( boost::ref(xml_stream) );
        }
    }
    
    void default_writeXMLToStream( ::CEGUI::XMLSerializer & xml_stream ) const  {
        CEGUI::Window::writeXMLToStream( boost::ref(xml_stream) );
    }

};

void register_MultiLineEditbox_class(){

    { //::CEGUI::MultiLineEditbox
        typedef bp::class_< MultiLineEditbox_wrapper, bp::bases< CEGUI::Window >, boost::noncopyable > MultiLineEditbox_exposer_t;
        MultiLineEditbox_exposer_t MultiLineEditbox_exposer = MultiLineEditbox_exposer_t( "MultiLineEditbox", "*!\n\
        \n\
           Base class for the multi-line edit box widget.\n\
        *\n", bp::init< CEGUI::String const &, CEGUI::String const & >(( bp::arg("type"), bp::arg("name") ), "*************************************************************************\n\
           Construction and Destruction\n\
        *************************************************************************\n\
        *!\n\
        \n\
           Constructor for the MultiLineEditbox base class.\n\
        *\n") );
        bp::scope MultiLineEditbox_scope( MultiLineEditbox_exposer );
        { //::CEGUI::MultiLineEditbox::LineInfo
            typedef bp::class_< CEGUI::MultiLineEditbox::LineInfo > LineInfo_exposer_t;
            LineInfo_exposer_t LineInfo_exposer = LineInfo_exposer_t( "LineInfo", "*************************************************************************\n\
                Implementation struct\n\
            *************************************************************************\n\
            *!\n\
            \n\
                struct used to store information about a formatted line within the\n\
                paragraph.\n\
            *\n" );
            bp::scope LineInfo_scope( LineInfo_exposer );
            LineInfo_exposer.def_readwrite( "d_extent", &CEGUI::MultiLineEditbox::LineInfo::d_extent );
            LineInfo_exposer.def_readwrite( "d_length", &CEGUI::MultiLineEditbox::LineInfo::d_length );
            LineInfo_exposer.def_readwrite( "d_startIdx", &CEGUI::MultiLineEditbox::LineInfo::d_startIdx );
        }
        { //::CEGUI::MultiLineEditbox::clearSelection
        
            typedef void ( MultiLineEditbox_wrapper::*clearSelection_function_type )(  ) ;
            
            MultiLineEditbox_exposer.def( 
                "clearSelection"
                , clearSelection_function_type( &MultiLineEditbox_wrapper::clearSelection )
                , "*!\n\
            \n\
               Clear the current selection setting\n\
            *\n" );
        
        }
        { //::CEGUI::MultiLineEditbox::configureScrollbars
        
            typedef void ( MultiLineEditbox_wrapper::*configureScrollbars_function_type )(  ) ;
            
            MultiLineEditbox_exposer.def( 
                "configureScrollbars"
                , configureScrollbars_function_type( &MultiLineEditbox_wrapper::configureScrollbars )
                , "*!\n\
            \n\
               display required integrated scroll bars according to current state of the edit box and update\
               their values.\n\
            *\n" );
        
        }
        { //::CEGUI::MultiLineEditbox::ensureCaretIsVisible
        
            typedef void ( ::CEGUI::MultiLineEditbox::*ensureCaretIsVisible_function_type )(  ) ;
            
            MultiLineEditbox_exposer.def( 
                "ensureCaretIsVisible"
                , ensureCaretIsVisible_function_type( &::CEGUI::MultiLineEditbox::ensureCaretIsVisible )
                , "*!\n\
            \n\
               Scroll the view so that the current caret position is visible.\n\
            *\n" );
        
        }
        { //::CEGUI::MultiLineEditbox::eraseSelectedText
        
            typedef void ( MultiLineEditbox_wrapper::*eraseSelectedText_function_type )( bool ) ;
            
            MultiLineEditbox_exposer.def( 
                "eraseSelectedText"
                , eraseSelectedText_function_type( &MultiLineEditbox_wrapper::eraseSelectedText )
                , ( bp::arg("modify_text")=(bool)(true) )
                , "*!\n\
               \n\
                  Erase the currently selected text.\n\
            \n\
               @param modify_text\n\
                  when true, the actual text will be modified.  When false, everything is done except erasing\
                  the characters.\n\
               *\n" );
        
        }
        { //::CEGUI::MultiLineEditbox::formatText
        
            typedef void ( ::CEGUI::MultiLineEditbox::*formatText_function_type )( bool const ) ;
            
            MultiLineEditbox_exposer.def( 
                "formatText"
                , formatText_function_type( &::CEGUI::MultiLineEditbox::formatText )
                , ( bp::arg("update_scrollbars") )
                , "*!\n\
                \n\
                    Format the text into lines as dictated by the formatting options.\n\
            \n\
                @param update_scrollbars \n\
                    - true if scrollbar configuration should be performed.\n\
                    - false if scrollbar configuration should not be performed.\n\
                *\n" );
        
        }
        { //::CEGUI::MultiLineEditbox::formatText
        
            typedef void ( MultiLineEditbox_wrapper::*formatText_function_type )(  ) ;
            
            MultiLineEditbox_exposer.def( 
                "formatText"
                , formatText_function_type( &MultiLineEditbox_wrapper::formatText )
                , "*************************************************************************\n\
               Implementation Methods\n\
            *************************************************************************\n\
            *!\n\
            \n\
               Format the text into lines as needed by the current formatting options.\n\
              deprecated\n\
                 This is deprecated in favour of the version taking a boolean.\n\
            *\n" );
        
        }
        { //::CEGUI::MultiLineEditbox::getCaretIndex
        
            typedef ::size_t ( ::CEGUI::MultiLineEditbox::*getCaretIndex_function_type )(  ) const;
            
            MultiLineEditbox_exposer.def( 
                "getCaretIndex"
                , getCaretIndex_function_type( &::CEGUI::MultiLineEditbox::getCaretIndex )
                , "*!\n\
               \n\
                  return the current position of the caret.\n\
            \n\
               @return\n\
                  Index of the insert caret relative to the start of the text.\n\
               *\n" );
        
        }
        { //::CEGUI::MultiLineEditbox::getFormattedLines
        
            typedef ::std::vector< CEGUI::MultiLineEditbox::LineInfo > const & ( ::CEGUI::MultiLineEditbox::*getFormattedLines_function_type )(  ) const;
            
            MultiLineEditbox_exposer.def( 
                "getFormattedLines"
                , getFormattedLines_function_type( &::CEGUI::MultiLineEditbox::getFormattedLines )
                , bp::return_value_policy< bp::copy_const_reference >()
                , "get d_lines\n" );
        
        }
        { //::CEGUI::MultiLineEditbox::getHorzScrollbar
        
            typedef ::CEGUI::Scrollbar * ( ::CEGUI::MultiLineEditbox::*getHorzScrollbar_function_type )(  ) const;
            
            MultiLineEditbox_exposer.def( 
                "getHorzScrollbar"
                , getHorzScrollbar_function_type( &::CEGUI::MultiLineEditbox::getHorzScrollbar )
                , bp::return_value_policy< bp::reference_existing_object >()
                , "*!\n\
                \n\
                    Return a pointer to the horizontal scrollbar component widget for this\n\
                    MultiLineEditbox.\n\
            \n\
                @return\n\
                    Pointer to a Scrollbar object.\n\
            \n\
                @exception UnknownObjectException\n\
                    Thrown if the horizontal Scrollbar component does not exist.\n\
                *\n" );
        
        }
        { //::CEGUI::MultiLineEditbox::getLineNumberFromIndex
        
            typedef ::size_t ( ::CEGUI::MultiLineEditbox::*getLineNumberFromIndex_function_type )( ::size_t ) const;
            
            MultiLineEditbox_exposer.def( 
                "getLineNumberFromIndex"
                , getLineNumberFromIndex_function_type( &::CEGUI::MultiLineEditbox::getLineNumberFromIndex )
                , ( bp::arg("index") )
                , "*!\n\
            \n\
                Return the line number a given index falls on with the current formatting.  Will return last\
                line\n\
                if index is out of range.\n\
            *\n" );
        
        }
        { //::CEGUI::MultiLineEditbox::getMaxTextLength
        
            typedef ::size_t ( ::CEGUI::MultiLineEditbox::*getMaxTextLength_function_type )(  ) const;
            
            MultiLineEditbox_exposer.def( 
                "getMaxTextLength"
                , getMaxTextLength_function_type( &::CEGUI::MultiLineEditbox::getMaxTextLength )
                , "*!\n\
               \n\
                  return the maximum text length set for this edit box.\n\
            \n\
               @return\n\
                  The maximum number of code points (characters) that can be entered into this edit box.\n\
               *\n" );
        
        }
        { //::CEGUI::MultiLineEditbox::getNextTokenLength
        
            typedef ::size_t ( MultiLineEditbox_wrapper::*getNextTokenLength_function_type )( ::CEGUI::String const &,::size_t ) const;
            
            MultiLineEditbox_exposer.def( 
                "getNextTokenLength"
                , getNextTokenLength_function_type( &MultiLineEditbox_wrapper::getNextTokenLength )
                , ( bp::arg("text"), bp::arg("start_idx") )
                , "*!\n\
               \n\
                  Return the length of the next token in String  text starting at index  start_idx.\n\
            \n\
               \note\n\
                  Any single whitespace character is one token, any group of other characters is a token.\n\
               \n\
               @return\n\
                  The code point length of the token.\n\
               *\n" );
        
        }
        { //::CEGUI::MultiLineEditbox::getSelectionBrushImage
        
            typedef ::CEGUI::Image const * ( ::CEGUI::MultiLineEditbox::*getSelectionBrushImage_function_type )(  ) const;
            
            MultiLineEditbox_exposer.def( 
                "getSelectionBrushImage"
                , getSelectionBrushImage_function_type( &::CEGUI::MultiLineEditbox::getSelectionBrushImage )
                , bp::return_value_policy< bp::reference_existing_object >()
                , "selection brush image property support\n" );
        
        }
        { //::CEGUI::MultiLineEditbox::getSelectionEndIndex
        
            typedef ::size_t ( ::CEGUI::MultiLineEditbox::*getSelectionEndIndex_function_type )(  ) const;
            
            MultiLineEditbox_exposer.def( 
                "getSelectionEndIndex"
                , getSelectionEndIndex_function_type( &::CEGUI::MultiLineEditbox::getSelectionEndIndex )
                , "*!\n\
               \n\
                  return the current selection end point.\n\
            \n\
               @return\n\
                  Index of the selection end point relative to the start of the text.  If no selection is\
                  defined this function returns\n\
                  the position of the caret.\n\
               *\n" );
        
        }
        { //::CEGUI::MultiLineEditbox::getSelectionLength
        
            typedef ::size_t ( ::CEGUI::MultiLineEditbox::*getSelectionLength_function_type )(  ) const;
            
            MultiLineEditbox_exposer.def( 
                "getSelectionLength"
                , getSelectionLength_function_type( &::CEGUI::MultiLineEditbox::getSelectionLength )
                , "*!\n\
               \n\
                  return the length of the current selection (in code points  characters).\n\
            \n\
               @return\n\
                  Number of code points (or characters) contained within the currently defined selection.\n\
               *\n" );
        
        }
        { //::CEGUI::MultiLineEditbox::getSelectionStartIndex
        
            typedef ::size_t ( ::CEGUI::MultiLineEditbox::*getSelectionStartIndex_function_type )(  ) const;
            
            MultiLineEditbox_exposer.def( 
                "getSelectionStartIndex"
                , getSelectionStartIndex_function_type( &::CEGUI::MultiLineEditbox::getSelectionStartIndex )
                , "*!\n\
               \n\
                  return the current selection start point.\n\
            \n\
               @return\n\
                  Index of the selection start point relative to the start of the text.  If no selection is\
                  defined this function returns\n\
                  the position of the caret.\n\
               *\n" );
        
        }
        { //::CEGUI::MultiLineEditbox::getTextIndexFromPosition
        
            typedef ::size_t ( MultiLineEditbox_wrapper::*getTextIndexFromPosition_function_type )( ::CEGUI::Vector2f const & ) const;
            
            MultiLineEditbox_exposer.def( 
                "getTextIndexFromPosition"
                , getTextIndexFromPosition_function_type( &MultiLineEditbox_wrapper::getTextIndexFromPosition )
                , ( bp::arg("pt") )
                , "*!\n\
               \n\
                  Return the text code point index that is rendered closest to screen position  pt.\n\
            \n\
               @param pt\n\
                  Point object describing a position on the screen in pixels.\n\
            \n\
               @return\n\
                  Code point index into the text that is rendered closest to screen position  pt.\n\
               *\n" );
        
        }
        { //::CEGUI::MultiLineEditbox::getTextRenderArea
        
            typedef ::CEGUI::Rectf ( ::CEGUI::MultiLineEditbox::*getTextRenderArea_function_type )(  ) const;
            
            MultiLineEditbox_exposer.def( 
                "getTextRenderArea"
                , getTextRenderArea_function_type( &::CEGUI::MultiLineEditbox::getTextRenderArea )
                , "*!\n\
                \n\
                    Return a Rect object describing, in un-clipped pixels, the window relative area\n\
                    that the text should be rendered in to.\n\
            \n\
                @return\n\
                    Rect object describing the area of the Window to be used for rendering text.\n\
                *\n" );
        
        }
        { //::CEGUI::MultiLineEditbox::getVertScrollbar
        
            typedef ::CEGUI::Scrollbar * ( ::CEGUI::MultiLineEditbox::*getVertScrollbar_function_type )(  ) const;
            
            MultiLineEditbox_exposer.def( 
                "getVertScrollbar"
                , getVertScrollbar_function_type( &::CEGUI::MultiLineEditbox::getVertScrollbar )
                , bp::return_value_policy< bp::reference_existing_object >()
                , "*!\n\
                \n\
                    Return a pointer to the vertical scrollbar component widget for this\n\
                    MultiLineEditbox.\n\
            \n\
                @return\n\
                    Pointer to a Scrollbar object.\n\
            \n\
                @exception UnknownObjectException\n\
                    Thrown if the vertical Scrollbar component does not exist.\n\
                *\n" );
        
        }
        { //::CEGUI::MultiLineEditbox::handleBackspace
        
            typedef void ( MultiLineEditbox_wrapper::*handleBackspace_function_type )(  ) ;
            
            MultiLineEditbox_exposer.def( 
                "handleBackspace"
                , handleBackspace_function_type( &MultiLineEditbox_wrapper::handleBackspace )
                , "*!\n\
            \n\
               Processing for backspace key\n\
            *\n" );
        
        }
        { //::CEGUI::MultiLineEditbox::handleCharLeft
        
            typedef void ( MultiLineEditbox_wrapper::*handleCharLeft_function_type )( ::CEGUI::uint ) ;
            
            MultiLineEditbox_exposer.def( 
                "handleCharLeft"
                , handleCharLeft_function_type( &MultiLineEditbox_wrapper::handleCharLeft )
                , ( bp::arg("sysKeys") )
                , "*!\n\
            \n\
               Processing to move caret one character left\n\
            *\n" );
        
        }
        { //::CEGUI::MultiLineEditbox::handleCharRight
        
            typedef void ( MultiLineEditbox_wrapper::*handleCharRight_function_type )( ::CEGUI::uint ) ;
            
            MultiLineEditbox_exposer.def( 
                "handleCharRight"
                , handleCharRight_function_type( &MultiLineEditbox_wrapper::handleCharRight )
                , ( bp::arg("sysKeys") )
                , "*!\n\
            \n\
               Processing to move caret one character right\n\
            *\n" );
        
        }
        { //::CEGUI::MultiLineEditbox::handleDelete
        
            typedef void ( MultiLineEditbox_wrapper::*handleDelete_function_type )(  ) ;
            
            MultiLineEditbox_exposer.def( 
                "handleDelete"
                , handleDelete_function_type( &MultiLineEditbox_wrapper::handleDelete )
                , "*!\n\
            \n\
               Processing for Delete key\n\
            *\n" );
        
        }
        { //::CEGUI::MultiLineEditbox::handleDocEnd
        
            typedef void ( MultiLineEditbox_wrapper::*handleDocEnd_function_type )( ::CEGUI::uint ) ;
            
            MultiLineEditbox_exposer.def( 
                "handleDocEnd"
                , handleDocEnd_function_type( &MultiLineEditbox_wrapper::handleDocEnd )
                , ( bp::arg("sysKeys") )
                , "*!\n\
            \n\
               Processing to move caret to the end of the text\n\
            *\n" );
        
        }
        { //::CEGUI::MultiLineEditbox::handleDocHome
        
            typedef void ( MultiLineEditbox_wrapper::*handleDocHome_function_type )( ::CEGUI::uint ) ;
            
            MultiLineEditbox_exposer.def( 
                "handleDocHome"
                , handleDocHome_function_type( &MultiLineEditbox_wrapper::handleDocHome )
                , ( bp::arg("sysKeys") )
                , "*!\n\
            \n\
               Processing to move caret to the start of the text.\n\
            *\n" );
        
        }
        { //::CEGUI::MultiLineEditbox::handleLineDown
        
            typedef void ( MultiLineEditbox_wrapper::*handleLineDown_function_type )( ::CEGUI::uint ) ;
            
            MultiLineEditbox_exposer.def( 
                "handleLineDown"
                , handleLineDown_function_type( &MultiLineEditbox_wrapper::handleLineDown )
                , ( bp::arg("sysKeys") )
                , "*!\n\
            \n\
               Processing to move caret down a line.\n\
            *\n" );
        
        }
        { //::CEGUI::MultiLineEditbox::handleLineEnd
        
            typedef void ( MultiLineEditbox_wrapper::*handleLineEnd_function_type )( ::CEGUI::uint ) ;
            
            MultiLineEditbox_exposer.def( 
                "handleLineEnd"
                , handleLineEnd_function_type( &MultiLineEditbox_wrapper::handleLineEnd )
                , ( bp::arg("sysKeys") )
                , "*!\n\
            \n\
               Processing to move caret to the end of the current line\n\
            *\n" );
        
        }
        { //::CEGUI::MultiLineEditbox::handleLineHome
        
            typedef void ( MultiLineEditbox_wrapper::*handleLineHome_function_type )( ::CEGUI::uint ) ;
            
            MultiLineEditbox_exposer.def( 
                "handleLineHome"
                , handleLineHome_function_type( &MultiLineEditbox_wrapper::handleLineHome )
                , ( bp::arg("sysKeys") )
                , "*!\n\
            \n\
               Processing to move caret to the start of the current line.\n\
            *\n" );
        
        }
        { //::CEGUI::MultiLineEditbox::handleLineUp
        
            typedef void ( MultiLineEditbox_wrapper::*handleLineUp_function_type )( ::CEGUI::uint ) ;
            
            MultiLineEditbox_exposer.def( 
                "handleLineUp"
                , handleLineUp_function_type( &MultiLineEditbox_wrapper::handleLineUp )
                , ( bp::arg("sysKeys") )
                , "*!\n\
            \n\
               Processing to move caret up a line.\n\
            *\n" );
        
        }
        { //::CEGUI::MultiLineEditbox::handleNewLine
        
            typedef void ( MultiLineEditbox_wrapper::*handleNewLine_function_type )( ::CEGUI::uint ) ;
            
            MultiLineEditbox_exposer.def( 
                "handleNewLine"
                , handleNewLine_function_type( &MultiLineEditbox_wrapper::handleNewLine )
                , ( bp::arg("sysKeys") )
                , "*!\n\
            \n\
               Processing to insert a new line  paragraph.\n\
            *\n" );
        
        }
        { //::CEGUI::MultiLineEditbox::handlePageDown
        
            typedef void ( MultiLineEditbox_wrapper::*handlePageDown_function_type )( ::CEGUI::uint ) ;
            
            MultiLineEditbox_exposer.def( 
                "handlePageDown"
                , handlePageDown_function_type( &MultiLineEditbox_wrapper::handlePageDown )
                , ( bp::arg("sysKeys") )
                , "*!\n\
            \n\
                Processing to move caret one page down\n\
            *\n" );
        
        }
        { //::CEGUI::MultiLineEditbox::handlePageUp
        
            typedef void ( MultiLineEditbox_wrapper::*handlePageUp_function_type )( ::CEGUI::uint ) ;
            
            MultiLineEditbox_exposer.def( 
                "handlePageUp"
                , handlePageUp_function_type( &MultiLineEditbox_wrapper::handlePageUp )
                , ( bp::arg("sysKeys") )
                , "*!\n\
            \n\
                Processing to move caret one page up\n\
            *\n" );
        
        }
        { //::CEGUI::MultiLineEditbox::handleWordLeft
        
            typedef void ( MultiLineEditbox_wrapper::*handleWordLeft_function_type )( ::CEGUI::uint ) ;
            
            MultiLineEditbox_exposer.def( 
                "handleWordLeft"
                , handleWordLeft_function_type( &MultiLineEditbox_wrapper::handleWordLeft )
                , ( bp::arg("sysKeys") )
                , "*!\n\
            \n\
               Processing to move caret one word left\n\
            *\n" );
        
        }
        { //::CEGUI::MultiLineEditbox::handleWordRight
        
            typedef void ( MultiLineEditbox_wrapper::*handleWordRight_function_type )( ::CEGUI::uint ) ;
            
            MultiLineEditbox_exposer.def( 
                "handleWordRight"
                , handleWordRight_function_type( &MultiLineEditbox_wrapper::handleWordRight )
                , ( bp::arg("sysKeys") )
                , "*!\n\
            \n\
               Processing to move caret one word right\n\
            *\n" );
        
        }
        { //::CEGUI::MultiLineEditbox::handle_scrollChange
        
            typedef bool ( MultiLineEditbox_wrapper::*handle_scrollChange_function_type )( ::CEGUI::EventArgs const & ) ;
            
            MultiLineEditbox_exposer.def( 
                "handle_scrollChange"
                , handle_scrollChange_function_type( &MultiLineEditbox_wrapper::handle_scrollChange )
                , ( bp::arg("args") )
                , "*!\n\
            \n\
               Internal handler that is triggered when the user interacts with the scrollbars.\n\
             *\n" );
        
        }
        { //::CEGUI::MultiLineEditbox::handle_vertScrollbarVisibilityChanged
        
            typedef bool ( MultiLineEditbox_wrapper::*handle_vertScrollbarVisibilityChanged_function_type )( ::CEGUI::EventArgs const & ) ;
            
            MultiLineEditbox_exposer.def( 
                "handle_vertScrollbarVisibilityChanged"
                , handle_vertScrollbarVisibilityChanged_function_type( &MultiLineEditbox_wrapper::handle_vertScrollbarVisibilityChanged )
                , ( bp::arg("arg0") )
                , "handler triggered when vertical scrollbar is shown or hidden\n" );
        
        }
        { //::CEGUI::MultiLineEditbox::hasInputFocus
        
            typedef bool ( ::CEGUI::MultiLineEditbox::*hasInputFocus_function_type )(  ) const;
            
            MultiLineEditbox_exposer.def( 
                "hasInputFocus"
                , hasInputFocus_function_type( &::CEGUI::MultiLineEditbox::hasInputFocus )
                , "*************************************************************************\n\
                  Accessor Functions\n\
               *************************************************************************\n\
               *!\n\
               \n\
                  return true if the edit box has input focus.\n\
            \n\
               @return\n\
                  - true if the edit box has keyboard input focus.\n\
                  - false if the edit box does not have keyboard input focus.\n\
               *\n" );
        
        }
        { //::CEGUI::MultiLineEditbox::initialiseComponents
        
            typedef void ( ::CEGUI::MultiLineEditbox::*initialiseComponents_function_type )(  ) ;
            typedef void ( MultiLineEditbox_wrapper::*default_initialiseComponents_function_type )(  ) ;
            
            MultiLineEditbox_exposer.def( 
                "initialiseComponents"
                , initialiseComponents_function_type(&::CEGUI::MultiLineEditbox::initialiseComponents)
                , default_initialiseComponents_function_type(&MultiLineEditbox_wrapper::default_initialiseComponents) );
        
        }
        { //::CEGUI::MultiLineEditbox::isReadOnly
        
            typedef bool ( ::CEGUI::MultiLineEditbox::*isReadOnly_function_type )(  ) const;
            
            MultiLineEditbox_exposer.def( 
                "isReadOnly"
                , isReadOnly_function_type( &::CEGUI::MultiLineEditbox::isReadOnly )
                , "*!\n\
               \n\
                  return true if the edit box is read-only.\n\
            \n\
               @return\n\
                  - true if the edit box is read only and can't be edited by the user.\n\
                  - false if the edit box is not read only and may be edited by the user.\n\
               *\n" );
        
        }
        { //::CEGUI::MultiLineEditbox::isVertScrollbarAlwaysShown
        
            typedef bool ( ::CEGUI::MultiLineEditbox::*isVertScrollbarAlwaysShown_function_type )(  ) const;
            
            MultiLineEditbox_exposer.def( 
                "isVertScrollbarAlwaysShown"
                , isVertScrollbarAlwaysShown_function_type( &::CEGUI::MultiLineEditbox::isVertScrollbarAlwaysShown )
                , "*!\n\
               \n\
                  Return whether the vertical scroll bar is always shown.\n\
            \n\
               @return\n\
                  - true if the scroll bar will always be shown even if it is not required.\n\
                  - false if the scroll bar will only be shown when it is required.\n\
               *\n" );
        
        }
        { //::CEGUI::MultiLineEditbox::isWordWrapped
        
            typedef bool ( ::CEGUI::MultiLineEditbox::*isWordWrapped_function_type )(  ) const;
            
            MultiLineEditbox_exposer.def( 
                "isWordWrapped"
                , isWordWrapped_function_type( &::CEGUI::MultiLineEditbox::isWordWrapped )
                , "*!\n\
               \n\
                  Return whether the text in the edit box will be word-wrapped.\n\
            \n\
               @return\n\
                  - true if the text will be word-wrapped at the edges of the widget frame.\n\
                  - false if text will not be word-wrapped (a scroll bar will be used to access long text\
                  lines).\n\
               *\n" );
        
        }
        { //::CEGUI::MultiLineEditbox::onCaptureLost
        
            typedef void ( MultiLineEditbox_wrapper::*onCaptureLost_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            MultiLineEditbox_exposer.def( 
                "onCaptureLost"
                , onCaptureLost_function_type( &MultiLineEditbox_wrapper::default_onCaptureLost )
                , ( bp::arg("e") ) );
        
        }
        { //::CEGUI::MultiLineEditbox::onCaretMoved
        
            typedef void ( MultiLineEditbox_wrapper::*onCaretMoved_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            MultiLineEditbox_exposer.def( 
                "onCaretMoved"
                , onCaretMoved_function_type( &MultiLineEditbox_wrapper::onCaretMoved )
                , ( bp::arg("e") )
                , "*!\n\
            \n\
               Handler called when the caret moves.\n\
            *\n" );
        
        }
        { //::CEGUI::MultiLineEditbox::onCharacter
        
            typedef void ( MultiLineEditbox_wrapper::*onCharacter_function_type )( ::CEGUI::KeyEventArgs & ) ;
            
            MultiLineEditbox_exposer.def( 
                "onCharacter"
                , onCharacter_function_type( &MultiLineEditbox_wrapper::default_onCharacter )
                , ( bp::arg("e") ) );
        
        }
        { //::CEGUI::MultiLineEditbox::onEditboxFullEvent
        
            typedef void ( MultiLineEditbox_wrapper::*onEditboxFullEvent_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            MultiLineEditbox_exposer.def( 
                "onEditboxFullEvent"
                , onEditboxFullEvent_function_type( &MultiLineEditbox_wrapper::onEditboxFullEvent )
                , ( bp::arg("e") )
                , "*!\n\
            \n\
               Handler called when the edit box is full\n\
            *\n" );
        
        }
        { //::CEGUI::MultiLineEditbox::onFontChanged
        
            typedef void ( MultiLineEditbox_wrapper::*onFontChanged_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            MultiLineEditbox_exposer.def( 
                "onFontChanged"
                , onFontChanged_function_type( &MultiLineEditbox_wrapper::default_onFontChanged )
                , ( bp::arg("e") ) );
        
        }
        { //::CEGUI::MultiLineEditbox::onHorzScrollbarModeChanged
        
            typedef void ( MultiLineEditbox_wrapper::*onHorzScrollbarModeChanged_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            MultiLineEditbox_exposer.def( 
                "onHorzScrollbarModeChanged"
                , onHorzScrollbarModeChanged_function_type( &MultiLineEditbox_wrapper::onHorzScrollbarModeChanged )
                , ( bp::arg("e") )
                , "*!\n\
            \n\
               Handler called when 'always show' setting for the horizontal scroll bar changes.\n\
            *\n" );
        
        }
        { //::CEGUI::MultiLineEditbox::onKeyDown
        
            typedef void ( MultiLineEditbox_wrapper::*onKeyDown_function_type )( ::CEGUI::KeyEventArgs & ) ;
            
            MultiLineEditbox_exposer.def( 
                "onKeyDown"
                , onKeyDown_function_type( &MultiLineEditbox_wrapper::default_onKeyDown )
                , ( bp::arg("e") ) );
        
        }
        { //::CEGUI::MultiLineEditbox::onMaximumTextLengthChanged
        
            typedef void ( MultiLineEditbox_wrapper::*onMaximumTextLengthChanged_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            MultiLineEditbox_exposer.def( 
                "onMaximumTextLengthChanged"
                , onMaximumTextLengthChanged_function_type( &MultiLineEditbox_wrapper::onMaximumTextLengthChanged )
                , ( bp::arg("e") )
                , "*!\n\
            \n\
               Handler called when the maximum text length for the edit box changes\n\
            *\n" );
        
        }
        { //::CEGUI::MultiLineEditbox::onMouseButtonDown
        
            typedef void ( MultiLineEditbox_wrapper::*onMouseButtonDown_function_type )( ::CEGUI::MouseEventArgs & ) ;
            
            MultiLineEditbox_exposer.def( 
                "onMouseButtonDown"
                , onMouseButtonDown_function_type( &MultiLineEditbox_wrapper::default_onMouseButtonDown )
                , ( bp::arg("e") )
                , "*************************************************************************\n\
               Overridden event handlers\n\
            *************************************************************************\n" );
        
        }
        { //::CEGUI::MultiLineEditbox::onMouseButtonUp
        
            typedef void ( MultiLineEditbox_wrapper::*onMouseButtonUp_function_type )( ::CEGUI::MouseEventArgs & ) ;
            
            MultiLineEditbox_exposer.def( 
                "onMouseButtonUp"
                , onMouseButtonUp_function_type( &MultiLineEditbox_wrapper::default_onMouseButtonUp )
                , ( bp::arg("e") )
                , "*************************************************************************\n\
               Overridden event handlers\n\
            *************************************************************************\n" );
        
        }
        { //::CEGUI::MultiLineEditbox::onMouseDoubleClicked
        
            typedef void ( MultiLineEditbox_wrapper::*onMouseDoubleClicked_function_type )( ::CEGUI::MouseEventArgs & ) ;
            
            MultiLineEditbox_exposer.def( 
                "onMouseDoubleClicked"
                , onMouseDoubleClicked_function_type( &MultiLineEditbox_wrapper::default_onMouseDoubleClicked )
                , ( bp::arg("e") ) );
        
        }
        { //::CEGUI::MultiLineEditbox::onMouseMove
        
            typedef void ( MultiLineEditbox_wrapper::*onMouseMove_function_type )( ::CEGUI::MouseEventArgs & ) ;
            
            MultiLineEditbox_exposer.def( 
                "onMouseMove"
                , onMouseMove_function_type( &MultiLineEditbox_wrapper::default_onMouseMove )
                , ( bp::arg("e") ) );
        
        }
        { //::CEGUI::MultiLineEditbox::onMouseTripleClicked
        
            typedef void ( MultiLineEditbox_wrapper::*onMouseTripleClicked_function_type )( ::CEGUI::MouseEventArgs & ) ;
            
            MultiLineEditbox_exposer.def( 
                "onMouseTripleClicked"
                , onMouseTripleClicked_function_type( &MultiLineEditbox_wrapper::default_onMouseTripleClicked )
                , ( bp::arg("e") ) );
        
        }
        { //::CEGUI::MultiLineEditbox::onMouseWheel
        
            typedef void ( MultiLineEditbox_wrapper::*onMouseWheel_function_type )( ::CEGUI::MouseEventArgs & ) ;
            
            MultiLineEditbox_exposer.def( 
                "onMouseWheel"
                , onMouseWheel_function_type( &MultiLineEditbox_wrapper::default_onMouseWheel )
                , ( bp::arg("e") ) );
        
        }
        { //::CEGUI::MultiLineEditbox::onReadOnlyChanged
        
            typedef void ( MultiLineEditbox_wrapper::*onReadOnlyChanged_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            MultiLineEditbox_exposer.def( 
                "onReadOnlyChanged"
                , onReadOnlyChanged_function_type( &MultiLineEditbox_wrapper::onReadOnlyChanged )
                , ( bp::arg("e") )
                , "*************************************************************************\n\
               New event handlers\n\
            *************************************************************************\n\
            *!\n\
            \n\
               Handler called when the read-only state of the edit box changes\n\
            *\n" );
        
        }
        { //::CEGUI::MultiLineEditbox::onSized
        
            typedef void ( MultiLineEditbox_wrapper::*onSized_function_type )( ::CEGUI::ElementEventArgs & ) ;
            
            MultiLineEditbox_exposer.def( 
                "onSized"
                , onSized_function_type( &MultiLineEditbox_wrapper::default_onSized )
                , ( bp::arg("e") ) );
        
        }
        { //::CEGUI::MultiLineEditbox::onTextChanged
        
            typedef void ( MultiLineEditbox_wrapper::*onTextChanged_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            MultiLineEditbox_exposer.def( 
                "onTextChanged"
                , onTextChanged_function_type( &MultiLineEditbox_wrapper::default_onTextChanged )
                , ( bp::arg("e") ) );
        
        }
        { //::CEGUI::MultiLineEditbox::onTextSelectionChanged
        
            typedef void ( MultiLineEditbox_wrapper::*onTextSelectionChanged_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            MultiLineEditbox_exposer.def( 
                "onTextSelectionChanged"
                , onTextSelectionChanged_function_type( &MultiLineEditbox_wrapper::onTextSelectionChanged )
                , ( bp::arg("e") )
                , "*!\n\
            \n\
               Handler called when the text selection changes\n\
            *\n" );
        
        }
        { //::CEGUI::MultiLineEditbox::onVertScrollbarModeChanged
        
            typedef void ( MultiLineEditbox_wrapper::*onVertScrollbarModeChanged_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            MultiLineEditbox_exposer.def( 
                "onVertScrollbarModeChanged"
                , onVertScrollbarModeChanged_function_type( &MultiLineEditbox_wrapper::onVertScrollbarModeChanged )
                , ( bp::arg("e") )
                , "*!\n\
            \n\
               Handler called when the 'always show' setting for the vertical scroll bar changes.\n\
            *\n" );
        
        }
        { //::CEGUI::MultiLineEditbox::onWordWrapModeChanged
        
            typedef void ( MultiLineEditbox_wrapper::*onWordWrapModeChanged_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            MultiLineEditbox_exposer.def( 
                "onWordWrapModeChanged"
                , onWordWrapModeChanged_function_type( &MultiLineEditbox_wrapper::onWordWrapModeChanged )
                , ( bp::arg("e") )
                , "*!\n\
            \n\
               Handler called when the word wrap mode for the the edit box changes\n\
            *\n" );
        
        }
        { //::CEGUI::MultiLineEditbox::performCopy
        
            typedef bool ( ::CEGUI::MultiLineEditbox::*performCopy_function_type )( ::CEGUI::Clipboard & ) ;
            typedef bool ( MultiLineEditbox_wrapper::*default_performCopy_function_type )( ::CEGUI::Clipboard & ) ;
            
            MultiLineEditbox_exposer.def( 
                "performCopy"
                , performCopy_function_type(&::CEGUI::MultiLineEditbox::performCopy)
                , default_performCopy_function_type(&MultiLineEditbox_wrapper::default_performCopy)
                , ( bp::arg("clipboard") ) );
        
        }
        { //::CEGUI::MultiLineEditbox::performCut
        
            typedef bool ( ::CEGUI::MultiLineEditbox::*performCut_function_type )( ::CEGUI::Clipboard & ) ;
            typedef bool ( MultiLineEditbox_wrapper::*default_performCut_function_type )( ::CEGUI::Clipboard & ) ;
            
            MultiLineEditbox_exposer.def( 
                "performCut"
                , performCut_function_type(&::CEGUI::MultiLineEditbox::performCut)
                , default_performCut_function_type(&MultiLineEditbox_wrapper::default_performCut)
                , ( bp::arg("clipboard") ) );
        
        }
        { //::CEGUI::MultiLineEditbox::performPaste
        
            typedef bool ( ::CEGUI::MultiLineEditbox::*performPaste_function_type )( ::CEGUI::Clipboard & ) ;
            typedef bool ( MultiLineEditbox_wrapper::*default_performPaste_function_type )( ::CEGUI::Clipboard & ) ;
            
            MultiLineEditbox_exposer.def( 
                "performPaste"
                , performPaste_function_type(&::CEGUI::MultiLineEditbox::performPaste)
                , default_performPaste_function_type(&MultiLineEditbox_wrapper::default_performPaste)
                , ( bp::arg("clipboard") ) );
        
        }
        { //::CEGUI::MultiLineEditbox::setCaretIndex
        
            typedef void ( ::CEGUI::MultiLineEditbox::*setCaretIndex_function_type )( ::size_t ) ;
            
            MultiLineEditbox_exposer.def( 
                "setCaretIndex"
                , setCaretIndex_function_type( &::CEGUI::MultiLineEditbox::setCaretIndex )
                , ( bp::arg("caret_pos") )
                , "*!\n\
               \n\
                  Set the current position of the caret.\n\
            \n\
               @param caret_pos\n\
                  New index for the insert caret relative to the start of the text.  If the value specified is\
                  greater than the\n\
                  number of characters in the edit box, the caret is positioned at the end of the text.\n\
            \n\
               @return\n\
                  Nothing.\n\
               *\n" );
        
        }
        { //::CEGUI::MultiLineEditbox::setMaxTextLength
        
            typedef void ( ::CEGUI::MultiLineEditbox::*setMaxTextLength_function_type )( ::size_t ) ;
            
            MultiLineEditbox_exposer.def( 
                "setMaxTextLength"
                , setMaxTextLength_function_type( &::CEGUI::MultiLineEditbox::setMaxTextLength )
                , ( bp::arg("max_len") )
                , "*!\n\
               \n\
                  set the maximum text length for this edit box.\n\
            \n\
               @param max_len\n\
                  The maximum number of code points (characters) that can be entered into this Editbox.\n\
            \n\
               @return\n\
                  Nothing.\n\
               *\n" );
        
        }
        { //::CEGUI::MultiLineEditbox::setReadOnly
        
            typedef void ( ::CEGUI::MultiLineEditbox::*setReadOnly_function_type )( bool ) ;
            
            MultiLineEditbox_exposer.def( 
                "setReadOnly"
                , setReadOnly_function_type( &::CEGUI::MultiLineEditbox::setReadOnly )
                , ( bp::arg("setting") )
                , "*!\n\
               \n\
                  Specify whether the edit box is read-only.\n\
            \n\
               @param setting\n\
                  - true if the edit box is read only and can't be edited by the user.\n\
                  - false if the edit box is not read only and may be edited by the user.\n\
            \n\
               @return\n\
                  Nothing.\n\
               *\n" );
        
        }
        { //::CEGUI::MultiLineEditbox::setSelection
        
            typedef void ( ::CEGUI::MultiLineEditbox::*setSelection_function_type )( ::size_t,::size_t ) ;
            
            MultiLineEditbox_exposer.def( 
                "setSelection"
                , setSelection_function_type( &::CEGUI::MultiLineEditbox::setSelection )
                , ( bp::arg("start_pos"), bp::arg("end_pos") )
                , "*!\n\
               \n\
                  Define the current selection for the edit box\n\
            \n\
               @param start_pos\n\
                  Index of the starting point for the selection.  If this value is greater than the number of\
                  characters in the edit box, the\n\
                  selection start will be set to the end of the text.\n\
            \n\
               @param end_pos\n\
                  Index of the ending point for the selection.  If this value is greater than the number of\
                  characters in the edit box, the\n\
                  selection start will be set to the end of the text.\n\
            \n\
               @return\n\
                  Nothing.\n\
               *\n" );
        
        }
        { //::CEGUI::MultiLineEditbox::setSelectionBrushImage
        
            typedef void ( ::CEGUI::MultiLineEditbox::*setSelectionBrushImage_function_type )( ::CEGUI::Image const * ) ;
            
            MultiLineEditbox_exposer.def( 
                "setSelectionBrushImage"
                , setSelectionBrushImage_function_type( &::CEGUI::MultiLineEditbox::setSelectionBrushImage )
                , ( bp::arg("image") )
                , "selection brush image property support\n" );
        
        }
        { //::CEGUI::MultiLineEditbox::setSelectionLength
        
            typedef void ( ::CEGUI::MultiLineEditbox::*setSelectionLength_function_type )( ::size_t ) ;
            
            MultiLineEditbox_exposer.def( 
                "setSelectionLength"
                , setSelectionLength_function_type( &::CEGUI::MultiLineEditbox::setSelectionLength )
                , ( bp::arg("length") )
                , "*!\n\
                \n\
                    Define the current selection for the Editbox\n\
            \n\
                @param start_pos\n\
                    Length of the selection.\n\
            \n\
                @return\n\
                    Nothing.\n\
                *\n" );
        
        }
        { //::CEGUI::MultiLineEditbox::setSelectionStart
        
            typedef void ( ::CEGUI::MultiLineEditbox::*setSelectionStart_function_type )( ::size_t ) ;
            
            MultiLineEditbox_exposer.def( 
                "setSelectionStart"
                , setSelectionStart_function_type( &::CEGUI::MultiLineEditbox::setSelectionStart )
                , ( bp::arg("start_pos") )
                , "*!\n\
                \n\
                    Define the current selection start for the Editbox\n\
            \n\
                    @param start_pos\n\
                    Index of the starting point for the selection.  If this value is greater than the number of\
                    characters in the Editbox, the\n\
                    selection start will be set to the end of the text.\n\
            \n\
                @return\n\
                    Nothing.\n\
                *\n" );
        
        }
        { //::CEGUI::MultiLineEditbox::setShowVertScrollbar
        
            typedef void ( ::CEGUI::MultiLineEditbox::*setShowVertScrollbar_function_type )( bool ) ;
            
            MultiLineEditbox_exposer.def( 
                "setShowVertScrollbar"
                , setShowVertScrollbar_function_type( &::CEGUI::MultiLineEditbox::setShowVertScrollbar )
                , ( bp::arg("setting") )
                , "*!\n\
               \n\
                  Set whether the vertical scroll bar should always be shown.\n\
            \n\
               @param setting\n\
                  true if the vertical scroll bar should be shown even when it is not required.  false if the\
                  vertical\n\
                  scroll bar should only be shown when it is required.\n\
            \n\
               @return\n\
                  Nothing.\n\
               *\n" );
        
        }
        { //::CEGUI::MultiLineEditbox::setWordWrapping
        
            typedef void ( ::CEGUI::MultiLineEditbox::*setWordWrapping_function_type )( bool ) ;
            
            MultiLineEditbox_exposer.def( 
                "setWordWrapping"
                , setWordWrapping_function_type( &::CEGUI::MultiLineEditbox::setWordWrapping )
                , ( bp::arg("setting") )
                , "*!\n\
               \n\
                  Set whether the text will be word wrapped or not.\n\
            \n\
               @param setting\n\
                  - true if the text should word-wrap at the edges of the text box.\n\
                  - false if the text should not wrap, but a scroll bar should be used.\n\
            \n\
               @return\n\
                  Nothing.\n\
               *\n" );
        
        }
        { //::CEGUI::MultiLineEditbox::validateWindowRenderer
        
            typedef bool ( MultiLineEditbox_wrapper::*validateWindowRenderer_function_type )( ::CEGUI::WindowRenderer const * ) const;
            
            MultiLineEditbox_exposer.def( 
                "validateWindowRenderer"
                , validateWindowRenderer_function_type( &MultiLineEditbox_wrapper::default_validateWindowRenderer )
                , ( bp::arg("renderer") )
                , "validate window renderer\n" );
        
        }
        MultiLineEditbox_exposer.add_static_property( "EventCaretMoved"
                        , bp::make_getter( &CEGUI::MultiLineEditbox::EventCaretMoved
                                , bp::return_value_policy< bp::return_by_value >() ) );
        MultiLineEditbox_exposer.add_static_property( "EventEditboxFull"
                        , bp::make_getter( &CEGUI::MultiLineEditbox::EventEditboxFull
                                , bp::return_value_policy< bp::return_by_value >() ) );
        MultiLineEditbox_exposer.add_static_property( "EventHorzScrollbarModeChanged"
                        , bp::make_getter( &CEGUI::MultiLineEditbox::EventHorzScrollbarModeChanged
                                , bp::return_value_policy< bp::return_by_value >() ) );
        MultiLineEditbox_exposer.add_static_property( "EventMaximumTextLengthChanged"
                        , bp::make_getter( &CEGUI::MultiLineEditbox::EventMaximumTextLengthChanged
                                , bp::return_value_policy< bp::return_by_value >() ) );
        MultiLineEditbox_exposer.add_static_property( "EventReadOnlyModeChanged"
                        , bp::make_getter( &CEGUI::MultiLineEditbox::EventReadOnlyModeChanged
                                , bp::return_value_policy< bp::return_by_value >() ) );
        MultiLineEditbox_exposer.add_static_property( "EventTextSelectionChanged"
                        , bp::make_getter( &CEGUI::MultiLineEditbox::EventTextSelectionChanged
                                , bp::return_value_policy< bp::return_by_value >() ) );
        MultiLineEditbox_exposer.add_static_property( "EventVertScrollbarModeChanged"
                        , bp::make_getter( &CEGUI::MultiLineEditbox::EventVertScrollbarModeChanged
                                , bp::return_value_policy< bp::return_by_value >() ) );
        MultiLineEditbox_exposer.add_static_property( "EventWordWrapModeChanged"
                        , bp::make_getter( &CEGUI::MultiLineEditbox::EventWordWrapModeChanged
                                , bp::return_value_policy< bp::return_by_value >() ) );
        MultiLineEditbox_exposer.add_static_property( "HorzScrollbarName"
                        , bp::make_getter( &CEGUI::MultiLineEditbox::HorzScrollbarName
                                , bp::return_value_policy< bp::return_by_value >() ) );
        MultiLineEditbox_exposer.add_static_property( "VertScrollbarName"
                        , bp::make_getter( &CEGUI::MultiLineEditbox::VertScrollbarName
                                , bp::return_value_policy< bp::return_by_value >() ) );
        { //::CEGUI::Window::addChild_impl
        
            typedef void ( MultiLineEditbox_wrapper::*addChild_impl_function_type )( ::CEGUI::Element * ) ;
            
            MultiLineEditbox_exposer.def( 
                "addChild_impl"
                , addChild_impl_function_type( &MultiLineEditbox_wrapper::default_addChild_impl )
                , ( bp::arg("element") )
                , "*!\n\
            opydoc Element.addChild_impl\n\
            *\n" );
        
        }
        { //::CEGUI::Element::addElementProperties
        
            typedef void ( MultiLineEditbox_wrapper::*addElementProperties_function_type )(  ) ;
            
            MultiLineEditbox_exposer.def( 
                "addElementProperties"
                , addElementProperties_function_type( &MultiLineEditbox_wrapper::addElementProperties )
                , "*!\n\
            \n\
                Add standard CEGUI.Element properties.\n\
            *\n" );
        
        }
        { //::CEGUI::NamedElement::addNamedElementProperties
        
            typedef void ( MultiLineEditbox_wrapper::*addNamedElementProperties_function_type )(  ) ;
            
            MultiLineEditbox_exposer.def( 
                "addNamedElementProperties"
                , addNamedElementProperties_function_type( &MultiLineEditbox_wrapper::addNamedElementProperties )
                , "*!\n\
             Add standard CEGUI.NamedElement properties.\n\
            *\n" );
        
        }
        { //::CEGUI::Window::addWindowProperties
        
            typedef void ( MultiLineEditbox_wrapper::*addWindowProperties_function_type )(  ) ;
            
            MultiLineEditbox_exposer.def( 
                "addWindowProperties"
                , addWindowProperties_function_type( &MultiLineEditbox_wrapper::addWindowProperties )
                , "*!\n\
            \n\
                Add standard CEGUI.Window properties.\n\
            *\n" );
        
        }
        { //::CEGUI::Window::addWindowToDrawList
        
            typedef void ( MultiLineEditbox_wrapper::*addWindowToDrawList_function_type )( ::CEGUI::Window &,bool ) ;
            
            MultiLineEditbox_exposer.def( 
                "addWindowToDrawList"
                , addWindowToDrawList_function_type( &MultiLineEditbox_wrapper::addWindowToDrawList )
                , ( bp::arg("wnd"), bp::arg("at_back")=(bool)(false) )
                , "*!\n\
                \n\
                    Add the given window to the drawing list at an appropriate position for\n\
                    it's settings and the required direction.  Basically, when  at_back\n\
                    is false, the window will appear in front of all other windows with the\n\
                    same 'always on top' setting.  When  at_back is true, the window will\n\
                    appear behind all other windows wih the same 'always on top' setting.\n\
            \n\
                @param wnd\n\
                    Window object to be added to the drawing list.\n\
            \n\
                @param at_back\n\
                    Indicates whether the window should be placed at the back of other\n\
                    windows in the same group. If this is false, the window is placed in\n\
                    front of other windows in the group.\n\
            \n\
                @return\n\
                    Nothing.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::allocateRenderingWindow
        
            typedef void ( MultiLineEditbox_wrapper::*allocateRenderingWindow_function_type )(  ) ;
            
            MultiLineEditbox_exposer.def( 
                "allocateRenderingWindow"
                , allocateRenderingWindow_function_type( &MultiLineEditbox_wrapper::allocateRenderingWindow )
                , "! helper to create and setup the auto RenderingWindow surface\n" );
        
        }
        { //::CEGUI::Window::banPropertiesForAutoWindow
        
            typedef void ( MultiLineEditbox_wrapper::*banPropertiesForAutoWindow_function_type )(  ) ;
            
            MultiLineEditbox_exposer.def( 
                "banPropertiesForAutoWindow"
                , banPropertiesForAutoWindow_function_type( &MultiLineEditbox_wrapper::default_banPropertiesForAutoWindow ) );
        
        }
        { //::CEGUI::Window::beginInitialisation
        
            typedef void ( ::CEGUI::Window::*beginInitialisation_function_type )(  ) ;
            typedef void ( MultiLineEditbox_wrapper::*default_beginInitialisation_function_type )(  ) ;
            
            MultiLineEditbox_exposer.def( 
                "beginInitialisation"
                , beginInitialisation_function_type(&::CEGUI::Window::beginInitialisation)
                , default_beginInitialisation_function_type(&MultiLineEditbox_wrapper::default_beginInitialisation) );
        
        }
        { //::CEGUI::Window::bufferGeometry
        
            typedef void ( MultiLineEditbox_wrapper::*bufferGeometry_function_type )( ::CEGUI::RenderingContext const & ) ;
            
            MultiLineEditbox_exposer.def( 
                "bufferGeometry"
                , bufferGeometry_function_type( &MultiLineEditbox_wrapper::bufferGeometry )
                , ( bp::arg("ctx") )
                , "*!\n\
                \n\
                    Perform drawing operations concerned with generating and buffering\n\
                    window geometry.\n\
            \n\
                \note\n\
                    This function is a sub-function of drawSelf; it is provided to make it\n\
                    easier to override drawSelf without needing to duplicate large sections\n\
                    of the code from the default implementation.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::cleanupChildren
        
            typedef void ( MultiLineEditbox_wrapper::*cleanupChildren_function_type )(  ) ;
            
            MultiLineEditbox_exposer.def( 
                "cleanupChildren"
                , cleanupChildren_function_type( &MultiLineEditbox_wrapper::default_cleanupChildren )
                , "*!\n\
            \n\
                Cleanup child windows\n\
            *\n" );
        
        }
        { //::CEGUI::Window::cloneChildWidgetsTo
        
            typedef void ( ::CEGUI::Window::*cloneChildWidgetsTo_function_type )( ::CEGUI::Window & ) const;
            typedef void ( MultiLineEditbox_wrapper::*default_cloneChildWidgetsTo_function_type )( ::CEGUI::Window & ) const;
            
            MultiLineEditbox_exposer.def( 
                "cloneChildWidgetsTo"
                , cloneChildWidgetsTo_function_type(&::CEGUI::Window::cloneChildWidgetsTo)
                , default_cloneChildWidgetsTo_function_type(&MultiLineEditbox_wrapper::default_cloneChildWidgetsTo)
                , ( bp::arg("target") ) );
        
        }
        { //::CEGUI::Window::clonePropertiesTo
        
            typedef void ( ::CEGUI::Window::*clonePropertiesTo_function_type )( ::CEGUI::Window & ) const;
            typedef void ( MultiLineEditbox_wrapper::*default_clonePropertiesTo_function_type )( ::CEGUI::Window & ) const;
            
            MultiLineEditbox_exposer.def( 
                "clonePropertiesTo"
                , clonePropertiesTo_function_type(&::CEGUI::Window::clonePropertiesTo)
                , default_clonePropertiesTo_function_type(&MultiLineEditbox_wrapper::default_clonePropertiesTo)
                , ( bp::arg("target") ) );
        
        }
        { //::CEGUI::Window::destroy
        
            typedef void ( ::CEGUI::Window::*destroy_function_type )(  ) ;
            typedef void ( MultiLineEditbox_wrapper::*default_destroy_function_type )(  ) ;
            
            MultiLineEditbox_exposer.def( 
                "destroy"
                , destroy_function_type(&::CEGUI::Window::destroy)
                , default_destroy_function_type(&MultiLineEditbox_wrapper::default_destroy) );
        
        }
        { //::CEGUI::Window::drawSelf
        
            typedef void ( MultiLineEditbox_wrapper::*drawSelf_function_type )( ::CEGUI::RenderingContext const & ) ;
            
            MultiLineEditbox_exposer.def( 
                "drawSelf"
                , drawSelf_function_type( &MultiLineEditbox_wrapper::default_drawSelf )
                , ( bp::arg("ctx") )
                , "*!\n\
                \n\
                    Perform the actual rendering for this Window.\n\
            \n\
                @param ctx\n\
                    RenderingContext holding the details of the RenderingSurface to be\n\
                    used for the Window rendering operations.\n\
            \n\
                @return\n\
                    Nothing\n\
                *\n" );
        
        }
        { //::CEGUI::Window::endInitialisation
        
            typedef void ( ::CEGUI::Window::*endInitialisation_function_type )(  ) ;
            typedef void ( MultiLineEditbox_wrapper::*default_endInitialisation_function_type )(  ) ;
            
            MultiLineEditbox_exposer.def( 
                "endInitialisation"
                , endInitialisation_function_type(&::CEGUI::Window::endInitialisation)
                , default_endInitialisation_function_type(&MultiLineEditbox_wrapper::default_endInitialisation) );
        
        }
        { //::CEGUI::Element::fireAreaChangeEvents
        
            typedef void ( MultiLineEditbox_wrapper::*fireAreaChangeEvents_function_type )( bool const,bool const ) ;
            
            MultiLineEditbox_exposer.def( 
                "fireAreaChangeEvents"
                , fireAreaChangeEvents_function_type( &MultiLineEditbox_wrapper::fireAreaChangeEvents )
                , ( bp::arg("moved"), bp::arg("sized") )
                , "! helper to fire events based on changes to area rect\n" );
        
        }
        { //::CEGUI::EventSet::fireEvent
        
            typedef void ( ::CEGUI::EventSet::*fireEvent_function_type )( ::CEGUI::String const &,::CEGUI::EventArgs &,::CEGUI::String const & ) ;
            typedef void ( MultiLineEditbox_wrapper::*default_fireEvent_function_type )( ::CEGUI::String const &,::CEGUI::EventArgs &,::CEGUI::String const & ) ;
            
            MultiLineEditbox_exposer.def( 
                "fireEvent"
                , fireEvent_function_type(&::CEGUI::EventSet::fireEvent)
                , default_fireEvent_function_type(&MultiLineEditbox_wrapper::default_fireEvent)
                , ( bp::arg("name"), bp::arg("args"), bp::arg("eventNamespace")="" ) );
        
        }
        { //::CEGUI::EventSet::fireEvent_impl
        
            typedef void ( MultiLineEditbox_wrapper::*fireEvent_impl_function_type )( ::CEGUI::String const &,::CEGUI::EventArgs & ) ;
            
            MultiLineEditbox_exposer.def( 
                "fireEvent_impl"
                , fireEvent_impl_function_type( &MultiLineEditbox_wrapper::fireEvent_impl )
                , ( bp::arg("name"), bp::arg("args") )
                , "! Implementation event firing member\n" );
        
        }
        { //::CEGUI::Window::generateAutoRepeatEvent
        
            typedef void ( MultiLineEditbox_wrapper::*generateAutoRepeatEvent_function_type )( ::CEGUI::MouseButton ) ;
            
            MultiLineEditbox_exposer.def( 
                "generateAutoRepeatEvent"
                , generateAutoRepeatEvent_function_type( &MultiLineEditbox_wrapper::generateAutoRepeatEvent )
                , ( bp::arg("button") )
                , "*!\n\
            \n\
                Fires off a repeated mouse button down event for this window.\n\
            *\n" );
        
        }
        { //::CEGUI::NamedElement::getChildByNamePath_impl
        
            typedef ::CEGUI::NamedElement * ( MultiLineEditbox_wrapper::*getChildByNamePath_impl_function_type )( ::CEGUI::String const & ) const;
            
            MultiLineEditbox_exposer.def( 
                "getChildByNamePath_impl"
                , getChildByNamePath_impl_function_type( &MultiLineEditbox_wrapper::default_getChildByNamePath_impl )
                , ( bp::arg("name_path") )
                , bp::return_value_policy< bp::reference_existing_object >()
                , "*!\n\
             Retrieves a child at  name_path or 0 if none such exists\n\
            *\n" );
        
        }
        { //::CEGUI::NamedElement::getChildByNameRecursive_impl
        
            typedef ::CEGUI::NamedElement * ( MultiLineEditbox_wrapper::*getChildByNameRecursive_impl_function_type )( ::CEGUI::String const & ) const;
            
            MultiLineEditbox_exposer.def( 
                "getChildByNameRecursive_impl"
                , getChildByNameRecursive_impl_function_type( &MultiLineEditbox_wrapper::default_getChildByNameRecursive_impl )
                , ( bp::arg("name") )
                , bp::return_value_policy< bp::reference_existing_object >()
                , "*!\n\
             Finds a child by  name or 0 if none such exists\n\
            *\n" );
        
        }
        { //::CEGUI::Element::getClientChildContentArea
        
            typedef ::CEGUI::Element::CachedRectf const & ( ::CEGUI::Element::*getClientChildContentArea_function_type )(  ) const;
            
            MultiLineEditbox_exposer.def( 
                "getClientChildContentArea"
                , getClientChildContentArea_function_type(&::CEGUI::Element::getClientChildContentArea)
                , bp::return_value_policy< bp::copy_const_reference >() );
        
        }
        { //::CEGUI::Window::getHitTestRect_impl
        
            typedef ::CEGUI::Rectf ( MultiLineEditbox_wrapper::*getHitTestRect_impl_function_type )(  ) const;
            
            MultiLineEditbox_exposer.def( 
                "getHitTestRect_impl"
                , getHitTestRect_impl_function_type( &MultiLineEditbox_wrapper::default_getHitTestRect_impl )
                , "! Default implementation of function to return Window inner clipper area.\n\
            ! Default implementation of function to return Window hit-test area.\n" );
        
        }
        { //::CEGUI::Window::getInnerRectClipper_impl
        
            typedef ::CEGUI::Rectf ( MultiLineEditbox_wrapper::*getInnerRectClipper_impl_function_type )(  ) const;
            
            MultiLineEditbox_exposer.def( 
                "getInnerRectClipper_impl"
                , getInnerRectClipper_impl_function_type( &MultiLineEditbox_wrapper::default_getInnerRectClipper_impl )
                , "! Default implementation of function to return Window outer clipper area.\n\
            ! Default implementation of function to return Window inner clipper area.\n" );
        
        }
        { //::CEGUI::Element::getNonClientChildContentArea
        
            typedef ::CEGUI::Element::CachedRectf const & ( ::CEGUI::Element::*getNonClientChildContentArea_function_type )(  ) const;
            
            MultiLineEditbox_exposer.def( 
                "getNonClientChildContentArea"
                , getNonClientChildContentArea_function_type(&::CEGUI::Element::getNonClientChildContentArea)
                , bp::return_value_policy< bp::copy_const_reference >() );
        
        }
        { //::CEGUI::Window::getOuterRectClipper_impl
        
            typedef ::CEGUI::Rectf ( MultiLineEditbox_wrapper::*getOuterRectClipper_impl_function_type )(  ) const;
            
            MultiLineEditbox_exposer.def( 
                "getOuterRectClipper_impl"
                , getOuterRectClipper_impl_function_type( &MultiLineEditbox_wrapper::default_getOuterRectClipper_impl )
                , "! Default implementation of function to return Window outer clipper area.\n" );
        
        }
        { //::CEGUI::Window::getParentElementClipIntersection
        
            typedef ::CEGUI::Rectf ( MultiLineEditbox_wrapper::*getParentElementClipIntersection_function_type )( ::CEGUI::Rectf const & ) const;
            
            MultiLineEditbox_exposer.def( 
                "getParentElementClipIntersection"
                , getParentElementClipIntersection_function_type( &MultiLineEditbox_wrapper::getParentElementClipIntersection )
                , ( bp::arg("unclipped_area") )
                , "! helper function for calculating clipping rectangles.\n" );
        
        }
        { //::CEGUI::Window::getRenderedStringParser
        
            typedef ::CEGUI::RenderedStringParser & ( ::CEGUI::Window::*getRenderedStringParser_function_type )(  ) const;
            
            MultiLineEditbox_exposer.def( 
                "getRenderedStringParser"
                , getRenderedStringParser_function_type(&::CEGUI::Window::getRenderedStringParser)
                , bp::return_value_policy< bp::reference_existing_object >() );
        
        }
        { //::CEGUI::Window::getRenderingContext_impl
        
            typedef void ( ::CEGUI::Window::*getRenderingContext_impl_function_type )( ::CEGUI::RenderingContext & ) const;
            typedef void ( MultiLineEditbox_wrapper::*default_getRenderingContext_impl_function_type )( ::CEGUI::RenderingContext & ) const;
            
            MultiLineEditbox_exposer.def( 
                "getRenderingContext_impl"
                , getRenderingContext_impl_function_type(&::CEGUI::Window::getRenderingContext_impl)
                , default_getRenderingContext_impl_function_type(&MultiLineEditbox_wrapper::default_getRenderingContext_impl)
                , ( bp::arg("ctx") ) );
        
        }
        { //::CEGUI::Window::getRootContainerSize
        
            typedef ::CEGUI::Sizef const & ( ::CEGUI::Window::*getRootContainerSize_function_type )(  ) const;
            
            MultiLineEditbox_exposer.def( 
                "getRootContainerSize"
                , getRootContainerSize_function_type(&::CEGUI::Window::getRootContainerSize)
                , bp::return_value_policy< bp::copy_const_reference >() );
        
        }
        { //::CEGUI::EventSet::getScriptModule
        
            typedef ::CEGUI::ScriptModule * ( MultiLineEditbox_wrapper::*getScriptModule_function_type )(  ) const;
            
            MultiLineEditbox_exposer.def( 
                "getScriptModule"
                , getScriptModule_function_type( &MultiLineEditbox_wrapper::getScriptModule )
                , bp::return_value_policy< bp::reference_existing_object >()
                , "! Implementation event firing member\n\
            ! Helper to return the script module pointer or throw.\n" );
        
        }
        { //::CEGUI::Window::getUnclippedInnerRect_impl
        
            typedef ::CEGUI::Rectf ( MultiLineEditbox_wrapper::*getUnclippedInnerRect_impl_function_type )( bool ) const;
            
            MultiLineEditbox_exposer.def( 
                "getUnclippedInnerRect_impl"
                , getUnclippedInnerRect_impl_function_type( &MultiLineEditbox_wrapper::default_getUnclippedInnerRect_impl )
                , ( bp::arg("skipAllPixelAlignment") ) );
        
        }
        { //::CEGUI::Element::getUnclippedOuterRect_impl
        
            typedef ::CEGUI::Rectf ( MultiLineEditbox_wrapper::*getUnclippedOuterRect_impl_function_type )( bool ) const;
            
            MultiLineEditbox_exposer.def( 
                "getUnclippedOuterRect_impl"
                , getUnclippedOuterRect_impl_function_type( &MultiLineEditbox_wrapper::default_getUnclippedOuterRect_impl )
                , ( bp::arg("skipAllPixelAlignment") )
                , "! Default implementation of function to return Element's outer rect area.\n" );
        
        }
        { //::CEGUI::Window::getWindowAttachedToCommonAncestor
        
            typedef ::CEGUI::Window const * ( MultiLineEditbox_wrapper::*getWindowAttachedToCommonAncestor_function_type )( ::CEGUI::Window const & ) const;
            
            MultiLineEditbox_exposer.def( 
                "getWindowAttachedToCommonAncestor"
                , getWindowAttachedToCommonAncestor_function_type( &MultiLineEditbox_wrapper::getWindowAttachedToCommonAncestor )
                , ( bp::arg("wnd") )
                , bp::return_value_policy< bp::reference_existing_object >()
                , "*!\n\
            \n\
                Helper function to return the ancestor Window of a wnd that is attached\n\
                as a child to a window that is also an ancestor of a this.  Returns 0\n\
                if a wnd and a this are not part of the same hierachy.\n\
             *\n" );
        
        }
        { //::CEGUI::Window::handleFontRenderSizeChange
        
            typedef bool ( MultiLineEditbox_wrapper::*handleFontRenderSizeChange_function_type )( ::CEGUI::EventArgs const & ) ;
            
            MultiLineEditbox_exposer.def( 
                "handleFontRenderSizeChange"
                , handleFontRenderSizeChange_function_type( &MultiLineEditbox_wrapper::default_handleFontRenderSizeChange )
                , ( bp::arg("args") )
                , "! handler function for when font render size changes.\n" );
        
        }
        { //::CEGUI::Window::initialiseClippers
        
            typedef void ( MultiLineEditbox_wrapper::*initialiseClippers_function_type )( ::CEGUI::RenderingContext const & ) ;
            
            MultiLineEditbox_exposer.def( 
                "initialiseClippers"
                , initialiseClippers_function_type( &MultiLineEditbox_wrapper::initialiseClippers )
                , ( bp::arg("ctx") )
                , "! Helper to intialise the needed clipping for geometry and render surface.\n" );
        
        }
        { //::CEGUI::Window::invalidate_impl
        
            typedef void ( MultiLineEditbox_wrapper::*invalidate_impl_function_type )( bool const ) ;
            
            MultiLineEditbox_exposer.def( 
                "invalidate_impl"
                , invalidate_impl_function_type( &MultiLineEditbox_wrapper::invalidate_impl )
                , ( bp::arg("recursive") )
                , "! helper function to invalidate window and optionally child windows.\n" );
        
        }
        { //::CEGUI::Window::isHit
        
            typedef bool ( ::CEGUI::Window::*isHit_function_type )( ::CEGUI::Vector2f const &,bool const ) const;
            typedef bool ( MultiLineEditbox_wrapper::*default_isHit_function_type )( ::CEGUI::Vector2f const &,bool const ) const;
            
            MultiLineEditbox_exposer.def( 
                "isHit"
                , isHit_function_type(&::CEGUI::Window::isHit)
                , default_isHit_function_type(&MultiLineEditbox_wrapper::default_isHit)
                , ( bp::arg("position"), bp::arg("allow_disabled")=(bool const)(false) ) );
        
        }
        { //::CEGUI::Window::isHitTargetWindow
        
            typedef bool ( MultiLineEditbox_wrapper::*isHitTargetWindow_function_type )( ::CEGUI::Vector2f const &,bool ) const;
            
            MultiLineEditbox_exposer.def( 
                "isHitTargetWindow"
                , isHitTargetWindow_function_type( &MultiLineEditbox_wrapper::isHitTargetWindow )
                , ( bp::arg("position"), bp::arg("allow_disabled") ) );
        
        }
        { //::CEGUI::Element::isInnerRectSizeChanged
        
            typedef bool ( MultiLineEditbox_wrapper::*isInnerRectSizeChanged_function_type )(  ) const;
            
            MultiLineEditbox_exposer.def( 
                "isInnerRectSizeChanged"
                , isInnerRectSizeChanged_function_type( &MultiLineEditbox_wrapper::isInnerRectSizeChanged )
                , "! helper to return whether the inner rect size has changed\n" );
        
        }
        { //::CEGUI::Window::isPropertyAtDefault
        
            typedef bool ( MultiLineEditbox_wrapper::*isPropertyAtDefault_function_type )( ::CEGUI::Property const * ) const;
            
            MultiLineEditbox_exposer.def( 
                "isPropertyAtDefault"
                , isPropertyAtDefault_function_type( &MultiLineEditbox_wrapper::isPropertyAtDefault )
                , ( bp::arg("property") )
                , "*!\n\
            \n\
                Returns whether a property is at it's default value.\n\
                This function is different from Property.isDefatult as it takes the assigned look'n'feel\n\
                (if the is one) into account.\n\
            *\n" );
        
        }
        { //::CEGUI::Window::isTopOfZOrder
        
            typedef bool ( MultiLineEditbox_wrapper::*isTopOfZOrder_function_type )(  ) const;
            
            MultiLineEditbox_exposer.def( 
                "isTopOfZOrder"
                , isTopOfZOrder_function_type( &MultiLineEditbox_wrapper::isTopOfZOrder )
                , "*!\n\
                \n\
                    Return whether the window is at the top of the Z-Order.  This will\n\
                    correctly take into account 'Always on top' windows as needed.\n\
            \n\
                @return\n\
                    - true if the Window is at the top of the z-order in relation to sibling\n\
                      windows with the same 'always on top' setting.\n\
                    - false if the Window is not at the top of the z-order in relation to\n\
                      sibling windows with the same 'always on top' setting.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::layoutLookNFeelChildWidgets
        
            typedef void ( MultiLineEditbox_wrapper::*layoutLookNFeelChildWidgets_function_type )(  ) ;
            
            MultiLineEditbox_exposer.def( 
                "layoutLookNFeelChildWidgets"
                , layoutLookNFeelChildWidgets_function_type( &MultiLineEditbox_wrapper::layoutLookNFeelChildWidgets )
                , "mark the rect caches defined on Window invalid (does not affect Element)\n" );
        
        }
        { //::CEGUI::Window::markCachedWindowRectsInvalid
        
            typedef void ( MultiLineEditbox_wrapper::*markCachedWindowRectsInvalid_function_type )(  ) ;
            
            MultiLineEditbox_exposer.def( 
                "markCachedWindowRectsInvalid"
                , markCachedWindowRectsInvalid_function_type( &MultiLineEditbox_wrapper::markCachedWindowRectsInvalid )
                , "mark the rect caches defined on Window invalid (does not affect Element)\n" );
        
        }
        { //::CEGUI::Window::moveToFront_impl
        
            typedef bool ( MultiLineEditbox_wrapper::*moveToFront_impl_function_type )( bool ) ;
            
            MultiLineEditbox_exposer.def( 
                "moveToFront_impl"
                , moveToFront_impl_function_type( &MultiLineEditbox_wrapper::default_moveToFront_impl )
                , ( bp::arg("wasClicked") )
                , "*!\n\
                \n\
                    Implements move to front behavior.\n\
            \n\
                @return\n\
                    Should return true if some action was taken, or false if there was\n\
                    nothing to be done.\n\
                *\n" );
        
        }
        { //::CEGUI::Element::notifyChildrenOfSizeChange
        
            typedef void ( MultiLineEditbox_wrapper::*notifyChildrenOfSizeChange_function_type )( bool const,bool const ) ;
            
            MultiLineEditbox_exposer.def( 
                "notifyChildrenOfSizeChange"
                , notifyChildrenOfSizeChange_function_type( &MultiLineEditbox_wrapper::notifyChildrenOfSizeChange )
                , ( bp::arg("non_client"), bp::arg("client") ) );
        
        }
        { //::CEGUI::Window::notifyClippingChanged
        
            typedef void ( MultiLineEditbox_wrapper::*notifyClippingChanged_function_type )(  ) ;
            
            MultiLineEditbox_exposer.def( 
                "notifyClippingChanged"
                , notifyClippingChanged_function_type( &MultiLineEditbox_wrapper::notifyClippingChanged )
                , "*!\n\
            \n\
                Recursively inform all children that the clipping has changed and screen rects\n\
                needs to be recached.\n\
            *\n" );
        
        }
        { //::CEGUI::Window::notifyScreenAreaChanged
        
            typedef void ( ::CEGUI::Window::*notifyScreenAreaChanged_function_type )( bool ) ;
            typedef void ( MultiLineEditbox_wrapper::*default_notifyScreenAreaChanged_function_type )( bool ) ;
            
            MultiLineEditbox_exposer.def( 
                "notifyScreenAreaChanged"
                , notifyScreenAreaChanged_function_type(&::CEGUI::Window::notifyScreenAreaChanged)
                , default_notifyScreenAreaChanged_function_type(&MultiLineEditbox_wrapper::default_notifyScreenAreaChanged)
                , ( bp::arg("recursive")=(bool)(true) ) );
        
        }
        { //::CEGUI::Window::onActivated
        
            typedef void ( MultiLineEditbox_wrapper::*onActivated_function_type )( ::CEGUI::ActivationEventArgs & ) ;
            
            MultiLineEditbox_exposer.def( 
                "onActivated"
                , onActivated_function_type( &MultiLineEditbox_wrapper::default_onActivated )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when this window has become the active window.\n\
            \n\
                @param e\n\
                    ActivationEventArgs class whose 'otherWindow' field is set to the window\n\
                    that previously was active, or NULL for none.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onAlphaChanged
        
            typedef void ( MultiLineEditbox_wrapper::*onAlphaChanged_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            MultiLineEditbox_exposer.def( 
                "onAlphaChanged"
                , onAlphaChanged_function_type( &MultiLineEditbox_wrapper::default_onAlphaChanged )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the window's alpha blend value is changed.\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set to the window\n\
                    that triggered the event.  For this event the trigger window is always\n\
                    'this'.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onAlwaysOnTopChanged
        
            typedef void ( MultiLineEditbox_wrapper::*onAlwaysOnTopChanged_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            MultiLineEditbox_exposer.def( 
                "onAlwaysOnTopChanged"
                , onAlwaysOnTopChanged_function_type( &MultiLineEditbox_wrapper::default_onAlwaysOnTopChanged )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the window's always-on-top setting is changed.\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set to the window\n\
                    that triggered the event.  For this event the trigger window is always\n\
                    'this'.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onCaptureGained
        
            typedef void ( MultiLineEditbox_wrapper::*onCaptureGained_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            MultiLineEditbox_exposer.def( 
                "onCaptureGained"
                , onCaptureGained_function_type( &MultiLineEditbox_wrapper::default_onCaptureGained )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when this window gains capture of mouse inputs.\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set to the window\n\
                    that triggered the event.  For this event the trigger window is always\n\
                    'this'.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onChildAdded
        
            typedef void ( MultiLineEditbox_wrapper::*onChildAdded_function_type )( ::CEGUI::ElementEventArgs & ) ;
            
            MultiLineEditbox_exposer.def( 
                "onChildAdded"
                , onChildAdded_function_type( &MultiLineEditbox_wrapper::default_onChildAdded )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when a child window is added to this window.\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set to the window\n\
                    that has been added.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onChildRemoved
        
            typedef void ( MultiLineEditbox_wrapper::*onChildRemoved_function_type )( ::CEGUI::ElementEventArgs & ) ;
            
            MultiLineEditbox_exposer.def( 
                "onChildRemoved"
                , onChildRemoved_function_type( &MultiLineEditbox_wrapper::default_onChildRemoved )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when a child window is removed from this window.\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set the window\n\
                    that has been removed.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onClippingChanged
        
            typedef void ( MultiLineEditbox_wrapper::*onClippingChanged_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            MultiLineEditbox_exposer.def( 
                "onClippingChanged"
                , onClippingChanged_function_type( &MultiLineEditbox_wrapper::default_onClippingChanged )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the window's setting for being clipped by it's\n\
                    parent is changed.\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set to the window\n\
                    that triggered the event.  For this event the trigger window is always\n\
                    'this'.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onDeactivated
        
            typedef void ( MultiLineEditbox_wrapper::*onDeactivated_function_type )( ::CEGUI::ActivationEventArgs & ) ;
            
            MultiLineEditbox_exposer.def( 
                "onDeactivated"
                , onDeactivated_function_type( &MultiLineEditbox_wrapper::default_onDeactivated )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when this window has lost input focus and has been\n\
                    deactivated.\n\
            \n\
                @param e\n\
                    ActivationEventArgs object whose 'otherWindow' field is set to the\n\
                    window that has now become active, or NULL for none.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onDestructionStarted
        
            typedef void ( MultiLineEditbox_wrapper::*onDestructionStarted_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            MultiLineEditbox_exposer.def( 
                "onDestructionStarted"
                , onDestructionStarted_function_type( &MultiLineEditbox_wrapper::default_onDestructionStarted )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when this window's destruction sequence has begun.\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set to the window\n\
                    that triggered the event.  For this event the trigger window is always\n\
                    'this'.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onDisabled
        
            typedef void ( MultiLineEditbox_wrapper::*onDisabled_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            MultiLineEditbox_exposer.def( 
                "onDisabled"
                , onDisabled_function_type( &MultiLineEditbox_wrapper::default_onDisabled )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the window is disabled.\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set to the window\n\
                    that triggered the event.  For this event the trigger window is always\n\
                    'this'.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onDragDropItemDropped
        
            typedef void ( MultiLineEditbox_wrapper::*onDragDropItemDropped_function_type )( ::CEGUI::DragDropEventArgs & ) ;
            
            MultiLineEditbox_exposer.def( 
                "onDragDropItemDropped"
                , onDragDropItemDropped_function_type( &MultiLineEditbox_wrapper::default_onDragDropItemDropped )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when a DragContainer is dragged over this window.\n\
            \n\
                @param e\n\
                    DragDropEventArgs object initialised as follows:\n\
                    - window field is normaly set to point to 'this' window.\n\
                    - dragDropItem is a pointer to a DragContainer window that triggered\n\
                      the event.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onDragDropItemEnters
        
            typedef void ( MultiLineEditbox_wrapper::*onDragDropItemEnters_function_type )( ::CEGUI::DragDropEventArgs & ) ;
            
            MultiLineEditbox_exposer.def( 
                "onDragDropItemEnters"
                , onDragDropItemEnters_function_type( &MultiLineEditbox_wrapper::default_onDragDropItemEnters )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when a DragContainer is dragged over this window.\n\
            \n\
                @param e\n\
                    DragDropEventArgs object initialised as follows:\n\
                    - window field is normaly set to point to 'this' window.\n\
                    - dragDropItem is a pointer to a DragContainer window that triggered\n\
                      the event.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onDragDropItemLeaves
        
            typedef void ( MultiLineEditbox_wrapper::*onDragDropItemLeaves_function_type )( ::CEGUI::DragDropEventArgs & ) ;
            
            MultiLineEditbox_exposer.def( 
                "onDragDropItemLeaves"
                , onDragDropItemLeaves_function_type( &MultiLineEditbox_wrapper::default_onDragDropItemLeaves )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when a DragContainer is dragged over this window.\n\
            \n\
                @param e\n\
                    DragDropEventArgs object initialised as follows:\n\
                    - window field is normaly set to point to 'this' window.\n\
                    - dragDropItem is a pointer to a DragContainer window that triggered\n\
                      the event.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onEnabled
        
            typedef void ( MultiLineEditbox_wrapper::*onEnabled_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            MultiLineEditbox_exposer.def( 
                "onEnabled"
                , onEnabled_function_type( &MultiLineEditbox_wrapper::default_onEnabled )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the window is enabled.\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set to the window\n\
                    that triggered the event.  For this event the trigger window is always\n\
                    'this'.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onHidden
        
            typedef void ( MultiLineEditbox_wrapper::*onHidden_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            MultiLineEditbox_exposer.def( 
                "onHidden"
                , onHidden_function_type( &MultiLineEditbox_wrapper::default_onHidden )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the window is hidden.\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set to the window\n\
                    that triggered the event.  For this event the trigger window is always\n\
                    'this'.\n\
                *\n" );
        
        }
        { //::CEGUI::Element::onHorizontalAlignmentChanged
        
            typedef void ( MultiLineEditbox_wrapper::*onHorizontalAlignmentChanged_function_type )( ::CEGUI::ElementEventArgs & ) ;
            
            MultiLineEditbox_exposer.def( 
                "onHorizontalAlignmentChanged"
                , onHorizontalAlignmentChanged_function_type( &MultiLineEditbox_wrapper::default_onHorizontalAlignmentChanged )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the horizontal alignment setting for the element is\n\
                    changed.\n\
            \n\
                @param e\n\
                    ElementEventArgs object initialised as follows:\n\
                    - element field is set to point to the element object who's alignment has\n\
                      changed (typically 'this').\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onIDChanged
        
            typedef void ( MultiLineEditbox_wrapper::*onIDChanged_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            MultiLineEditbox_exposer.def( 
                "onIDChanged"
                , onIDChanged_function_type( &MultiLineEditbox_wrapper::default_onIDChanged )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the window's client assigned ID is changed.\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set to the window\n\
                    that triggered the event.  For this event the trigger window is always\n\
                    'this'.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onInheritsAlphaChanged
        
            typedef void ( MultiLineEditbox_wrapper::*onInheritsAlphaChanged_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            MultiLineEditbox_exposer.def( 
                "onInheritsAlphaChanged"
                , onInheritsAlphaChanged_function_type( &MultiLineEditbox_wrapper::default_onInheritsAlphaChanged )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the window's setting for inheriting alpha-blending\n\
                    is changed.\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set to the window\n\
                    that triggered the event.  For this event the trigger window is always\n\
                    'this'.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onInvalidated
        
            typedef void ( MultiLineEditbox_wrapper::*onInvalidated_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            MultiLineEditbox_exposer.def( 
                "onInvalidated"
                , onInvalidated_function_type( &MultiLineEditbox_wrapper::default_onInvalidated )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when this window gets invalidated.\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set to the window\n\
                    that triggered the event.  For this event the trigger window is always\n\
                    'this'.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onKeyUp
        
            typedef void ( MultiLineEditbox_wrapper::*onKeyUp_function_type )( ::CEGUI::KeyEventArgs & ) ;
            
            MultiLineEditbox_exposer.def( 
                "onKeyUp"
                , onKeyUp_function_type( &MultiLineEditbox_wrapper::default_onKeyUp )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when a key as been released while this window has input\n\
                    focus.\n\
            \n\
                @param e\n\
                    KeyEventArgs object whose 'scancode' field is set to the Key.Scan value\n\
                    representing the key that was released, and whose 'sysKeys' field\n\
                    represents the combination of SystemKey that were active when the event\n\
                    was generated.  All other fields should be considered as 'junk'.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onMarginChanged
        
            typedef void ( MultiLineEditbox_wrapper::*onMarginChanged_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            MultiLineEditbox_exposer.def( 
                "onMarginChanged"
                , onMarginChanged_function_type( &MultiLineEditbox_wrapper::default_onMarginChanged )
                , ( bp::arg("e") ) );
        
        }
        { //::CEGUI::Window::onMouseClicked
        
            typedef void ( MultiLineEditbox_wrapper::*onMouseClicked_function_type )( ::CEGUI::MouseEventArgs & ) ;
            
            MultiLineEditbox_exposer.def( 
                "onMouseClicked"
                , onMouseClicked_function_type( &MultiLineEditbox_wrapper::default_onMouseClicked )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when a mouse button has been clicked (that is depressed\n\
                    and then released, within a specified time) within this window's area.\n\
            \n\
                @param e\n\
                    MouseEventArgs object.  All fields are valid.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onMouseEnters
        
            typedef void ( MultiLineEditbox_wrapper::*onMouseEnters_function_type )( ::CEGUI::MouseEventArgs & ) ;
            
            MultiLineEditbox_exposer.def( 
                "onMouseEnters"
                , onMouseEnters_function_type( &MultiLineEditbox_wrapper::default_onMouseEnters )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the mouse cursor has entered this window's area and\n\
                    is actually over some part of this windows surface and not, for\n\
                    instance over a child window - even though technically in those cases\n\
                    the mouse is also within this Window's area, the handler will not be\n\
                    called.\n\
            \n\
                @param e\n\
                    MouseEventArgs object.  All fields are valid.\n\
            \n\
                @see\n\
                    Window.onMouseEntersArea\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onMouseEntersArea
        
            typedef void ( MultiLineEditbox_wrapper::*onMouseEntersArea_function_type )( ::CEGUI::MouseEventArgs & ) ;
            
            MultiLineEditbox_exposer.def( 
                "onMouseEntersArea"
                , onMouseEntersArea_function_type( &MultiLineEditbox_wrapper::default_onMouseEntersArea )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the mouse cursor has entered this window's area.\n\
            \n\
                @param e\n\
                    MouseEventArgs object.  All fields are valid.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onMouseLeaves
        
            typedef void ( MultiLineEditbox_wrapper::*onMouseLeaves_function_type )( ::CEGUI::MouseEventArgs & ) ;
            
            MultiLineEditbox_exposer.def( 
                "onMouseLeaves"
                , onMouseLeaves_function_type( &MultiLineEditbox_wrapper::default_onMouseLeaves )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the mouse cursor is no longer over this window's\n\
                    surface area.  This will be called when the mouse is not over a part\n\
                    of this Window's actual surface - even though technically the mouse is\n\
                    still within the Window's area, for example if the mouse moves over a\n\
                    child window.\n\
            \n\
                @param e\n\
                    MouseEventArgs object.  All fields are valid.\n\
            \n\
                @see\n\
                    Window.onMouseLeavesArea\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onMouseLeavesArea
        
            typedef void ( MultiLineEditbox_wrapper::*onMouseLeavesArea_function_type )( ::CEGUI::MouseEventArgs & ) ;
            
            MultiLineEditbox_exposer.def( 
                "onMouseLeavesArea"
                , onMouseLeavesArea_function_type( &MultiLineEditbox_wrapper::default_onMouseLeavesArea )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the mouse cursor has left this window's area.\n\
            \n\
                @param e\n\
                    MouseEventArgs object.  All fields are valid.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onMoved
        
            typedef void ( MultiLineEditbox_wrapper::*onMoved_function_type )( ::CEGUI::ElementEventArgs & ) ;
            
            MultiLineEditbox_exposer.def( 
                "onMoved"
                , onMoved_function_type( &MultiLineEditbox_wrapper::default_onMoved )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the window's position changes.\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set to the window\n\
                    that triggered the event.  For this event the trigger window is always\n\
                    'this'.\n\
                *\n" );
        
        }
        { //::CEGUI::NamedElement::onNameChanged
        
            typedef void ( MultiLineEditbox_wrapper::*onNameChanged_function_type )( ::CEGUI::NamedElementEventArgs & ) ;
            
            MultiLineEditbox_exposer.def( 
                "onNameChanged"
                , onNameChanged_function_type( &MultiLineEditbox_wrapper::default_onNameChanged )
                , ( bp::arg("e") )
                , "*!\n\
                 Handler called when the element's name changes.\n\
            \n\
                @param e\n\
                    NamedElementEventArgs object whose 'element' pointer field is set to the element\n\
                    that triggered the event. For this event the trigger element is always\n\
                    'this'.\n\
                *\n" );
        
        }
        { //::CEGUI::Element::onNonClientChanged
        
            typedef void ( MultiLineEditbox_wrapper::*onNonClientChanged_function_type )( ::CEGUI::ElementEventArgs & ) ;
            
            MultiLineEditbox_exposer.def( 
                "onNonClientChanged"
                , onNonClientChanged_function_type( &MultiLineEditbox_wrapper::default_onNonClientChanged )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the element's non-client setting, affecting it's\n\
                    position and size relative to it's parent is changed.\n\
            \n\
                @param e\n\
                    ElementEventArgs object whose 'element' pointer field is set to the element\n\
                    that triggered the event. For this event the trigger element is always\n\
                    'this'.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onParentDestroyChanged
        
            typedef void ( MultiLineEditbox_wrapper::*onParentDestroyChanged_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            MultiLineEditbox_exposer.def( 
                "onParentDestroyChanged"
                , onParentDestroyChanged_function_type( &MultiLineEditbox_wrapper::default_onParentDestroyChanged )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the window's setting for being destroyed\n\
                    automatically be it's parent is changed.\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set to the window\n\
                    that triggered the event.  For this event the trigger window is always\n\
                    'this'.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onParentSized
        
            typedef void ( MultiLineEditbox_wrapper::*onParentSized_function_type )( ::CEGUI::ElementEventArgs & ) ;
            
            MultiLineEditbox_exposer.def( 
                "onParentSized"
                , onParentSized_function_type( &MultiLineEditbox_wrapper::default_onParentSized )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when this window's parent window has been resized.  If\n\
                    this window is the root  GUI Sheet window, this call will be made when\n\
                    the display size changes.\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set the the\n\
                    window that caused the event; this is typically either this window's\n\
                    parent window, or NULL to indicate the screen size has changed.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onRenderingEnded
        
            typedef void ( MultiLineEditbox_wrapper::*onRenderingEnded_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            MultiLineEditbox_exposer.def( 
                "onRenderingEnded"
                , onRenderingEnded_function_type( &MultiLineEditbox_wrapper::default_onRenderingEnded )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when rendering for this window has ended.\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set to the window\n\
                    that triggered the event.  For this event the trigger window is always\n\
                    'this'.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onRenderingStarted
        
            typedef void ( MultiLineEditbox_wrapper::*onRenderingStarted_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            MultiLineEditbox_exposer.def( 
                "onRenderingStarted"
                , onRenderingStarted_function_type( &MultiLineEditbox_wrapper::default_onRenderingStarted )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when rendering for this window has started.\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set to the window\n\
                    that triggered the event.  For this event the trigger window is always\n\
                    'this'.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onRotated
        
            typedef void ( MultiLineEditbox_wrapper::*onRotated_function_type )( ::CEGUI::ElementEventArgs & ) ;
            
            MultiLineEditbox_exposer.def( 
                "onRotated"
                , onRotated_function_type( &MultiLineEditbox_wrapper::default_onRotated )
                , ( bp::arg("e") ) );
        
        }
        { //::CEGUI::Window::onShown
        
            typedef void ( MultiLineEditbox_wrapper::*onShown_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            MultiLineEditbox_exposer.def( 
                "onShown"
                , onShown_function_type( &MultiLineEditbox_wrapper::default_onShown )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the window is shown (made visible).\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set to the window\n\
                    that triggered the event.  For this event the trigger window is always\n\
                    'this'.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onTextParsingChanged
        
            typedef void ( MultiLineEditbox_wrapper::*onTextParsingChanged_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            MultiLineEditbox_exposer.def( 
                "onTextParsingChanged"
                , onTextParsingChanged_function_type( &MultiLineEditbox_wrapper::default_onTextParsingChanged )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the window's setting for whether text parsing is\n\
                    enabled is changed.\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set to the window\n\
                    that triggered the event.  For this event the trigger window is always\n\
                    'this'.\n\
                *\n" );
        
        }
        { //::CEGUI::Element::onVerticalAlignmentChanged
        
            typedef void ( MultiLineEditbox_wrapper::*onVerticalAlignmentChanged_function_type )( ::CEGUI::ElementEventArgs & ) ;
            
            MultiLineEditbox_exposer.def( 
                "onVerticalAlignmentChanged"
                , onVerticalAlignmentChanged_function_type( &MultiLineEditbox_wrapper::default_onVerticalAlignmentChanged )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the vertical alignment setting for the element is\n\
                    changed.\n\
            \n\
                @param e\n\
                    ElementEventArgs object initialised as follows:\n\
                    - element field is set to point to the element object who's alignment has\n\
                      changed (typically 'this').\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onWindowRendererAttached
        
            typedef void ( MultiLineEditbox_wrapper::*onWindowRendererAttached_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            MultiLineEditbox_exposer.def( 
                "onWindowRendererAttached"
                , onWindowRendererAttached_function_type( &MultiLineEditbox_wrapper::default_onWindowRendererAttached )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when a new window renderer object is attached.\n\
            \n\
                @param e\n\
                    WindowEventArgs object initialised as follows:\n\
                    - window field is set to point to the Window object that just got a new\n\
                      window renderer attached. (typically 'this').\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onWindowRendererDetached
        
            typedef void ( MultiLineEditbox_wrapper::*onWindowRendererDetached_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            MultiLineEditbox_exposer.def( 
                "onWindowRendererDetached"
                , onWindowRendererDetached_function_type( &MultiLineEditbox_wrapper::default_onWindowRendererDetached )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the currently attached window renderer object is detached.\n\
            \n\
                @param e\n\
                    WindowEventArgs object initialised as follows:\n\
                    - window field is set to point to the Window object that just got lost its\n\
                      window renderer. (typically 'this').\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onZChange_impl
        
            typedef void ( MultiLineEditbox_wrapper::*onZChange_impl_function_type )(  ) ;
            
            MultiLineEditbox_exposer.def( 
                "onZChange_impl"
                , onZChange_impl_function_type( &MultiLineEditbox_wrapper::default_onZChange_impl )
                , "*!\n\
            \n\
                Notify 'this' and all siblings of a ZOrder change event\n\
            *\n" );
        
        }
        { //::CEGUI::Window::onZChanged
        
            typedef void ( MultiLineEditbox_wrapper::*onZChanged_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            MultiLineEditbox_exposer.def( 
                "onZChanged"
                , onZChanged_function_type( &MultiLineEditbox_wrapper::default_onZChanged )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the z-order position of this window has changed.\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set to the window\n\
                    that triggered the event.  For this event the trigger window is always\n\
                    'this'.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::performChildWindowLayout
        
            typedef void ( ::CEGUI::Window::*performChildWindowLayout_function_type )( bool,bool ) ;
            typedef void ( MultiLineEditbox_wrapper::*default_performChildWindowLayout_function_type )( bool,bool ) ;
            
            MultiLineEditbox_exposer.def( 
                "performChildWindowLayout"
                , performChildWindowLayout_function_type(&::CEGUI::Window::performChildWindowLayout)
                , default_performChildWindowLayout_function_type(&MultiLineEditbox_wrapper::default_performChildWindowLayout)
                , ( bp::arg("nonclient_sized_hint")=(bool)(false), bp::arg("client_sized_hint")=(bool)(false) ) );
        
        }
        { //::CEGUI::Window::populateGeometryBuffer
        
            typedef void ( MultiLineEditbox_wrapper::*populateGeometryBuffer_function_type )(  ) ;
            
            MultiLineEditbox_exposer.def( 
                "populateGeometryBuffer"
                , populateGeometryBuffer_function_type( &MultiLineEditbox_wrapper::default_populateGeometryBuffer )
                , "*!\n\
                \n\
                    Update the rendering cache.\n\
            \n\
                    Populates the Window's GeometryBuffer ready for rendering.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::queueGeometry
        
            typedef void ( MultiLineEditbox_wrapper::*queueGeometry_function_type )( ::CEGUI::RenderingContext const & ) ;
            
            MultiLineEditbox_exposer.def( 
                "queueGeometry"
                , queueGeometry_function_type( &MultiLineEditbox_wrapper::queueGeometry )
                , ( bp::arg("ctx") )
                , "*!\n\
                \n\
                    Perform drawing operations concerned with positioning, clipping and\n\
                    queueing of window geometry to RenderingSurfaces.\n\
            \n\
                \note\n\
                    This function is a sub-function of drawSelf and is provided to make it\n\
                    easier to override drawSelf without needing to duplicate large sections\n\
                    of the code from the default implementation.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::releaseRenderingWindow
        
            typedef void ( MultiLineEditbox_wrapper::*releaseRenderingWindow_function_type )(  ) ;
            
            MultiLineEditbox_exposer.def( 
                "releaseRenderingWindow"
                , releaseRenderingWindow_function_type( &MultiLineEditbox_wrapper::releaseRenderingWindow )
                , "! helper to clean up the auto RenderingWindow surface\n" );
        
        }
        { //::CEGUI::Window::removeChild_impl
        
            typedef void ( MultiLineEditbox_wrapper::*removeChild_impl_function_type )( ::CEGUI::Element * ) ;
            
            MultiLineEditbox_exposer.def( 
                "removeChild_impl"
                , removeChild_impl_function_type( &MultiLineEditbox_wrapper::default_removeChild_impl )
                , ( bp::arg("element") )
                , "*!\n\
            opydoc Element.removeChild_impl\n\
            *\n" );
        
        }
        { //::CEGUI::Window::removeWindowFromDrawList
        
            typedef void ( MultiLineEditbox_wrapper::*removeWindowFromDrawList_function_type )( ::CEGUI::Window const & ) ;
            
            MultiLineEditbox_exposer.def( 
                "removeWindowFromDrawList"
                , removeWindowFromDrawList_function_type( &MultiLineEditbox_wrapper::removeWindowFromDrawList )
                , ( bp::arg("wnd") )
                , "*!\n\
                \n\
                    Removes the window from the drawing list.  If the window is not attached\n\
                    to the drawing list then nothing happens.\n\
            \n\
                @param wnd\n\
                    Window object to be removed from the drawing list.\n\
            \n\
                @return\n\
                    Nothing.\n\
                *\n" );
        
        }
        { //::CEGUI::Element::setArea
        
            typedef void ( ::CEGUI::Element::*setArea_function_type )( ::CEGUI::UVector2 const &,::CEGUI::USize const & ) ;
            typedef void ( MultiLineEditbox_wrapper::*default_setArea_function_type )( ::CEGUI::UVector2 const &,::CEGUI::USize const & ) ;
            
            MultiLineEditbox_exposer.def( 
                "setArea"
                , setArea_function_type(&::CEGUI::Element::setArea)
                , default_setArea_function_type(&MultiLineEditbox_wrapper::default_setArea)
                , ( bp::arg("pos"), bp::arg("size") ) );
        
        }
        { //::CEGUI::Element::setArea
        
            typedef void ( ::CEGUI::Element::*setArea_function_type )( ::CEGUI::UDim const &,::CEGUI::UDim const &,::CEGUI::UDim const &,::CEGUI::UDim const & ) ;
            
            MultiLineEditbox_exposer.def( 
                "setArea"
                , setArea_function_type( &::CEGUI::Element::setArea )
                , ( bp::arg("xpos"), bp::arg("ypos"), bp::arg("width"), bp::arg("height") )
                , "!  overload\n" );
        
        }
        { //::CEGUI::Element::setArea
        
            typedef void ( ::CEGUI::Element::*setArea_function_type )( ::CEGUI::URect const & ) ;
            
            MultiLineEditbox_exposer.def( 
                "setArea"
                , setArea_function_type( &::CEGUI::Element::setArea )
                , ( bp::arg("area") )
                , "!  overload\n" );
        
        }
        { //::CEGUI::Window::setArea_impl
        
            typedef void ( MultiLineEditbox_wrapper::*setArea_impl_function_type )( ::CEGUI::UVector2 const &,::CEGUI::USize const &,bool,bool ) ;
            
            MultiLineEditbox_exposer.def( 
                "setArea_impl"
                , setArea_impl_function_type( &MultiLineEditbox_wrapper::default_setArea_impl )
                , ( bp::arg("pos"), bp::arg("size"), bp::arg("topLeftSizing")=(bool)(false), bp::arg("fireEvents")=(bool)(true) )
                , "! opydoc Element.setArea_impl\n" );
        
        }
        { //::CEGUI::Element::setHorizontalAlignment
        
            typedef void ( ::CEGUI::Element::*setHorizontalAlignment_function_type )( ::CEGUI::HorizontalAlignment const ) ;
            typedef void ( MultiLineEditbox_wrapper::*default_setHorizontalAlignment_function_type )( ::CEGUI::HorizontalAlignment const ) ;
            
            MultiLineEditbox_exposer.def( 
                "setHorizontalAlignment"
                , setHorizontalAlignment_function_type(&::CEGUI::Element::setHorizontalAlignment)
                , default_setHorizontalAlignment_function_type(&MultiLineEditbox_wrapper::default_setHorizontalAlignment)
                , ( bp::arg("alignment") ) );
        
        }
        { //::CEGUI::Window::setLookNFeel
        
            typedef void ( ::CEGUI::Window::*setLookNFeel_function_type )( ::CEGUI::String const & ) ;
            typedef void ( MultiLineEditbox_wrapper::*default_setLookNFeel_function_type )( ::CEGUI::String const & ) ;
            
            MultiLineEditbox_exposer.def( 
                "setLookNFeel"
                , setLookNFeel_function_type(&::CEGUI::Window::setLookNFeel)
                , default_setLookNFeel_function_type(&MultiLineEditbox_wrapper::default_setLookNFeel)
                , ( bp::arg("look") ) );
        
        }
        { //::CEGUI::Window::setMargin
        
            typedef void ( ::CEGUI::Window::*setMargin_function_type )( ::CEGUI::UBox const & ) ;
            typedef void ( MultiLineEditbox_wrapper::*default_setMargin_function_type )( ::CEGUI::UBox const & ) ;
            
            MultiLineEditbox_exposer.def( 
                "setMargin"
                , setMargin_function_type(&::CEGUI::Window::setMargin)
                , default_setMargin_function_type(&MultiLineEditbox_wrapper::default_setMargin)
                , ( bp::arg("margin") ) );
        
        }
        { //::CEGUI::NamedElement::setName
        
            typedef void ( ::CEGUI::NamedElement::*setName_function_type )( ::CEGUI::String const & ) ;
            typedef void ( MultiLineEditbox_wrapper::*default_setName_function_type )( ::CEGUI::String const & ) ;
            
            MultiLineEditbox_exposer.def( 
                "setName"
                , setName_function_type(&::CEGUI::NamedElement::setName)
                , default_setName_function_type(&MultiLineEditbox_wrapper::default_setName)
                , ( bp::arg("name") ) );
        
        }
        { //::CEGUI::Window::setParent
        
            typedef void ( MultiLineEditbox_wrapper::*setParent_function_type )( ::CEGUI::Element * ) ;
            
            MultiLineEditbox_exposer.def( 
                "setParent"
                , setParent_function_type( &MultiLineEditbox_wrapper::default_setParent )
                , ( bp::arg("parent") )
                , "*!\n\
                \n\
                    Set the parent window for this window object.\n\
            \n\
                @param parent\n\
                    Pointer to a Window object that is to be assigned as the parent to this\n\
                    Window.\n\
            \n\
                @return\n\
                    Nothing\n\
                *\n" );
        
        }
        { //::CEGUI::Element::setVerticalAlignment
        
            typedef void ( ::CEGUI::Element::*setVerticalAlignment_function_type )( ::CEGUI::VerticalAlignment const ) ;
            typedef void ( MultiLineEditbox_wrapper::*default_setVerticalAlignment_function_type )( ::CEGUI::VerticalAlignment const ) ;
            
            MultiLineEditbox_exposer.def( 
                "setVerticalAlignment"
                , setVerticalAlignment_function_type(&::CEGUI::Element::setVerticalAlignment)
                , default_setVerticalAlignment_function_type(&MultiLineEditbox_wrapper::default_setVerticalAlignment)
                , ( bp::arg("alignment") ) );
        
        }
        { //::CEGUI::EventSet::subscribeScriptedEvent
        
            typedef ::CEGUI::RefCounted< CEGUI::BoundSlot > ( ::CEGUI::EventSet::*subscribeScriptedEvent_function_type )( ::CEGUI::String const &,::CEGUI::String const & ) ;
            typedef ::CEGUI::RefCounted< CEGUI::BoundSlot > ( MultiLineEditbox_wrapper::*default_subscribeScriptedEvent_function_type )( ::CEGUI::String const &,::CEGUI::String const & ) ;
            
            MultiLineEditbox_exposer.def( 
                "subscribeScriptedEvent"
                , subscribeScriptedEvent_function_type(&::CEGUI::EventSet::subscribeScriptedEvent)
                , default_subscribeScriptedEvent_function_type(&MultiLineEditbox_wrapper::default_subscribeScriptedEvent)
                , ( bp::arg("name"), bp::arg("subscriber_name") ) );
        
        }
        { //::CEGUI::EventSet::subscribeScriptedEvent
        
            typedef ::CEGUI::RefCounted< CEGUI::BoundSlot > ( ::CEGUI::EventSet::*subscribeScriptedEvent_function_type )( ::CEGUI::String const &,unsigned int,::CEGUI::String const & ) ;
            typedef ::CEGUI::RefCounted< CEGUI::BoundSlot > ( MultiLineEditbox_wrapper::*default_subscribeScriptedEvent_function_type )( ::CEGUI::String const &,unsigned int,::CEGUI::String const & ) ;
            
            MultiLineEditbox_exposer.def( 
                "subscribeScriptedEvent"
                , subscribeScriptedEvent_function_type(&::CEGUI::EventSet::subscribeScriptedEvent)
                , default_subscribeScriptedEvent_function_type(&MultiLineEditbox_wrapper::default_subscribeScriptedEvent)
                , ( bp::arg("name"), bp::arg("group"), bp::arg("subscriber_name") ) );
        
        }
        { //::CEGUI::Window::transferChildSurfaces
        
            typedef void ( MultiLineEditbox_wrapper::*transferChildSurfaces_function_type )(  ) ;
            
            MultiLineEditbox_exposer.def( 
                "transferChildSurfaces"
                , transferChildSurfaces_function_type( &MultiLineEditbox_wrapper::transferChildSurfaces )
                , "! transfer RenderingSurfaces to be owned by our target RenderingSurface.\n" );
        
        }
        { //::CEGUI::Window::update
        
            typedef void ( ::CEGUI::Window::*update_function_type )( float ) ;
            typedef void ( MultiLineEditbox_wrapper::*default_update_function_type )( float ) ;
            
            MultiLineEditbox_exposer.def( 
                "update"
                , update_function_type(&::CEGUI::Window::update)
                , default_update_function_type(&MultiLineEditbox_wrapper::default_update)
                , ( bp::arg("elapsed") ) );
        
        }
        { //::CEGUI::Window::updateGeometryRenderSettings
        
            typedef void ( MultiLineEditbox_wrapper::*updateGeometryRenderSettings_function_type )(  ) ;
            
            MultiLineEditbox_exposer.def( 
                "updateGeometryRenderSettings"
                , updateGeometryRenderSettings_function_type( &MultiLineEditbox_wrapper::updateGeometryRenderSettings )
                , "*!\n\
            \n\
                Update position and clip region on this Windows geometry  rendering\n\
                surface.\n\
            *\n" );
        
        }
        { //::CEGUI::Window::updateSelf
        
            typedef void ( MultiLineEditbox_wrapper::*updateSelf_function_type )( float ) ;
            
            MultiLineEditbox_exposer.def( 
                "updateSelf"
                , updateSelf_function_type( &MultiLineEditbox_wrapper::default_updateSelf )
                , ( bp::arg("elapsed") )
                , "*************************************************************************\n\
                    Implementation Functions\n\
                *************************************************************************\n\
                *!\n\
                \n\
                    Perform actual update processing for this Window.\n\
            \n\
                @param elapsed\n\
                    float value indicating the number of seconds elapsed since the last\n\
                    update call.\n\
            \n\
                @return\n\
                    Nothing.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::writeAutoChildWindowXML
        
            typedef bool ( MultiLineEditbox_wrapper::*writeAutoChildWindowXML_function_type )( ::CEGUI::XMLSerializer & ) const;
            
            MultiLineEditbox_exposer.def( 
                "writeAutoChildWindowXML"
                , writeAutoChildWindowXML_function_type( &MultiLineEditbox_wrapper::default_writeAutoChildWindowXML )
                , ( bp::arg("xml_stream") ) );
        
        }
        { //::CEGUI::Window::writeChildWindowsXML
        
            typedef int ( MultiLineEditbox_wrapper::*writeChildWindowsXML_function_type )( ::CEGUI::XMLSerializer & ) const;
            
            MultiLineEditbox_exposer.def( 
                "writeChildWindowsXML"
                , writeChildWindowsXML_function_type( &MultiLineEditbox_wrapper::default_writeChildWindowsXML )
                , ( bp::arg("xml_stream") ) );
        
        }
        { //::CEGUI::Window::writePropertiesXML
        
            typedef int ( MultiLineEditbox_wrapper::*writePropertiesXML_function_type )( ::CEGUI::XMLSerializer & ) const;
            
            MultiLineEditbox_exposer.def( 
                "writePropertiesXML"
                , writePropertiesXML_function_type( &MultiLineEditbox_wrapper::default_writePropertiesXML )
                , ( bp::arg("xml_stream") ) );
        
        }
        { //::CEGUI::Window::writeXMLToStream
        
            typedef void ( ::CEGUI::Window::*writeXMLToStream_function_type )( ::CEGUI::XMLSerializer & ) const;
            typedef void ( MultiLineEditbox_wrapper::*default_writeXMLToStream_function_type )( ::CEGUI::XMLSerializer & ) const;
            
            MultiLineEditbox_exposer.def( 
                "writeXMLToStream"
                , writeXMLToStream_function_type(&::CEGUI::Window::writeXMLToStream)
                , default_writeXMLToStream_function_type(&MultiLineEditbox_wrapper::default_writeXMLToStream)
                , ( bp::arg("xml_stream") ) );
        
        }
    }

}
